"use strict";
var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const React = require("react");
const _interopDefaultLegacy = /* @__PURE__ */ __name((e) => e && typeof e === "object" && "default" in e ? e : { default: e }, "_interopDefaultLegacy");
function _interopNamespace(e) {
  if (e && e.__esModule)
    return e;
  const n = Object.create(null, { [Symbol.toStringTag]: { value: "Module" } });
  if (e) {
    for (const k in e) {
      if (k !== "default") {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}
__name(_interopNamespace, "_interopNamespace");
const React__namespace = /* @__PURE__ */ _interopNamespace(React);
const React__default = /* @__PURE__ */ _interopDefaultLegacy(React);
class ExplainDataManager extends EventTarget {
  constructor() {
    super();
    this.explainData = {};
    this.currentTab = "profiler";
  }
  getExplainData() {
    return this.explainData;
  }
  getProfilerData() {
    return this.explainData.profiler || [];
  }
  getResolverCallsData() {
    return this.explainData.resolverCalls || [];
  }
  setExplain(explainData2) {
    this.explainData = explainData2 || {};
    this.dispatchEvent(new Event("updateExplainData"));
  }
  getCurrentTab() {
    return this.currentTab;
  }
  setCurrentTab(tab2) {
    this.currentTab = tab2;
  }
}
__name(ExplainDataManager, "ExplainDataManager");
const explainDataManager = new ExplainDataManager();
const colors = {
  low: "rgb(219 175 53)",
  medium: "rgb(255 165 0)",
  high: "rgb(255 78 78)",
  veryHigh: "rgb(255 0 0)",
  default: "inherit"
};
const thresholds = [
  {
    limit: 0.5,
    color: colors.low
  },
  {
    limit: 0.7,
    color: colors.medium
  },
  {
    limit: 0.9,
    color: colors.high
  },
  {
    limit: 0.99,
    color: colors.veryHigh
  }
];
const reverseThresholds = thresholds.reverse();
function plainToTree(data) {
  const tree = {
    path: "",
    children: {}
  };
  data.forEach((entry) => {
    getObjectByPath(tree, entry);
  });
  return tree;
}
__name(plainToTree, "plainToTree");
function enrichWithTotals(tree) {
  if (!Object.keys(tree.children).length) {
    tree.totalBegin = tree.begin;
    tree.totalEnd = tree.end;
    tree.totalTime = tree.end - tree.begin;
    return;
  }
  let max = 0;
  let min = tree.begin || Number.MAX_VALUE;
  Object.entries(tree.children).forEach(([key, value]) => {
    enrichWithTotals(value);
    max = Math.max(max, value.totalEnd);
    min = Math.min(min, value.totalBegin);
  });
  tree.totalBegin = min;
  tree.totalEnd = max;
  tree.totalTime = max - min;
}
__name(enrichWithTotals, "enrichWithTotals");
function getObjectByPath(root2, entry) {
  const path = entry.path.split(".");
  let currentRoot = root2;
  for (const index of path) {
    if (!currentRoot.children[index]) {
      currentRoot.children[index] = {
        children: {}
      };
    }
    currentRoot = currentRoot.children[index];
  }
  Object.assign(currentRoot, entry);
}
__name(getObjectByPath, "getObjectByPath");
function getTreeNodeByPath(root2, path) {
  const paths = path.split(".");
  let currentRoot = root2;
  let pathData = {};
  for (const index of paths) {
    pathData = currentRoot[index];
    currentRoot = currentRoot[index].children;
  }
  return pathData;
}
__name(getTreeNodeByPath, "getTreeNodeByPath");
function treeToPlain(tree, data) {
  const dataTotals = data.map(
    ({ path }) => getTreeNodeByPath(tree.children, path)
  );
  return dataTotals.map(({ children: children2, ...datumTotals }) => datumTotals);
}
__name(treeToPlain, "treeToPlain");
function appendTotalsToExplainResponse(originalData) {
  const tree = plainToTree(originalData);
  enrichWithTotals(tree);
  const dataTotals = treeToPlain(tree, originalData);
  return dataTotals;
}
__name(appendTotalsToExplainResponse, "appendTotalsToExplainResponse");
function saveExplainResponse(data) {
  const { explain } = data.extensions || {};
  if (explain && explain.profiler.data && explain.resolverCalls.data) {
    explainDataManager.setExplain({
      profiler: explain.profiler.data,
      resolverCalls: explain.resolverCalls.data
    });
  }
  return data;
}
__name(saveExplainResponse, "saveExplainResponse");
function parseFetchResponse(data) {
  return saveExplainResponse(data);
}
__name(parseFetchResponse, "parseFetchResponse");
function getColorByLimit(maxLimit) {
  var _a;
  return ((_a = reverseThresholds.find(({ limit }) => maxLimit >= limit)) == null ? void 0 : _a.color) || colors.default;
}
__name(getColorByLimit, "getColorByLimit");
const textShortener = /* @__PURE__ */ __name((text, maxCharacters, separator = "...") => {
  if (text.length < maxCharacters) {
    return text;
  }
  const charactersToBeRemoved = text.length - maxCharacters + separator.length;
  const initialString = text.substring(
    0,
    Math.floor((text.length - charactersToBeRemoved) / 2)
  );
  const finalString = text.substring(
    initialString.length + charactersToBeRemoved
  );
  return initialString + separator + finalString;
}, "textShortener");
const SvgArrow = /* @__PURE__ */ __name((props) => /* @__PURE__ */ React__namespace.createElement("svg", {
  enableBackground: "new 0 0 32 32",
  height: "32px",
  id: "Layer_1",
  viewBox: "0 0 32 32",
  width: "32px",
  xmlSpace: "preserve",
  xmlns: "http://www.w3.org/2000/svg",
  xmlnsXlink: "http://www.w3.org/1999/xlink",
  ...props
}, /* @__PURE__ */ React__namespace.createElement("path", {
  d: "M18.221,7.206l9.585,9.585c0.879,0.879,0.879,2.317,0,3.195l-0.8,0.801c-0.877,0.878-2.316,0.878-3.194,0  l-7.315-7.315l-7.315,7.315c-0.878,0.878-2.317,0.878-3.194,0l-0.8-0.801c-0.879-0.878-0.879-2.316,0-3.195l9.587-9.585  c0.471-0.472,1.103-0.682,1.723-0.647C17.115,6.524,17.748,6.734,18.221,7.206z",
  fill: "#515151"
})), "SvgArrow");
const SvgChart = /* @__PURE__ */ __name((props) => /* @__PURE__ */ React__namespace.createElement("svg", {
  id: "Capa_1",
  xmlns: "http://www.w3.org/2000/svg",
  xmlnsXlink: "http://www.w3.org/1999/xlink",
  x: "0px",
  y: "0px",
  width: "350px",
  height: "350px",
  viewBox: "0 0 350 350",
  style: {
    enableBackground: "new 0 0 350 350"
  },
  xmlSpace: "preserve",
  ...props
}, /* @__PURE__ */ React__namespace.createElement("g", null, /* @__PURE__ */ React__namespace.createElement("g", null, /* @__PURE__ */ React__namespace.createElement("polygon", {
  points: "40,310 40,0 0,0 0,350 350,350 350,310  "
}), /* @__PURE__ */ React__namespace.createElement("rect", {
  x: 69,
  y: 26,
  width: 82,
  height: 43.152
}), /* @__PURE__ */ React__namespace.createElement("rect", {
  x: 69,
  y: 96,
  width: 152,
  height: 43.152
}), /* @__PURE__ */ React__namespace.createElement("rect", {
  x: 69,
  y: 166,
  width: 103,
  height: 43.152
}), /* @__PURE__ */ React__namespace.createElement("rect", {
  x: 69,
  y: 236,
  width: 222,
  height: 43.152
}))), /* @__PURE__ */ React__namespace.createElement("g", null), /* @__PURE__ */ React__namespace.createElement("g", null), /* @__PURE__ */ React__namespace.createElement("g", null), /* @__PURE__ */ React__namespace.createElement("g", null), /* @__PURE__ */ React__namespace.createElement("g", null), /* @__PURE__ */ React__namespace.createElement("g", null), /* @__PURE__ */ React__namespace.createElement("g", null), /* @__PURE__ */ React__namespace.createElement("g", null), /* @__PURE__ */ React__namespace.createElement("g", null), /* @__PURE__ */ React__namespace.createElement("g", null), /* @__PURE__ */ React__namespace.createElement("g", null), /* @__PURE__ */ React__namespace.createElement("g", null), /* @__PURE__ */ React__namespace.createElement("g", null), /* @__PURE__ */ React__namespace.createElement("g", null), /* @__PURE__ */ React__namespace.createElement("g", null)), "SvgChart");
const useProfiler = /* @__PURE__ */ __name(() => {
  const initialProfiler = React.useMemo(
    () => appendTotalsToExplainResponse(explainDataManager.getProfilerData()),
    []
  );
  const [profiler, setProfiler] = React.useState(initialProfiler);
  const [defaultProfiler, setDefaultProfiler] = React.useState(initialProfiler);
  const [pathOrder, setPathOrder] = React.useState(0);
  const [timeOrder, setTimeOrder] = React.useState(0);
  const [totalOrder, setTotalOrder] = React.useState(0);
  const [limits, setLimits] = React.useState({
    time: 0,
    totalTime: 0,
    totalBegin: Number.MAX_VALUE,
    pathLength: 0
  });
  React.useEffect(() => {
    setLimits(
      defaultProfiler.reduce(
        (acc, curr) => {
          if (curr.time > acc.time) {
            acc.time = curr.time;
          }
          if (curr.totalTime > acc.totalTime) {
            acc.totalTime = curr.totalTime;
          }
          if (curr.totalBegin < acc.totalBegin) {
            acc.totalBegin = curr.totalBegin;
          }
          if (curr.path.length > acc.pathLength) {
            acc.pathLength = curr.path.length;
          }
          return acc;
        },
        { time: 0, totalTime: 0, totalBegin: Number.MAX_VALUE, pathLength: 0 }
      )
    );
  }, [defaultProfiler]);
  React.useEffect(() => {
    const eventListener = explainDataManager.addEventListener(
      "updateExplainData",
      (e, value) => {
        const profilerDataWithTotal = appendTotalsToExplainResponse(
          e.target.explainData.profiler
        );
        setDefaultProfiler(() => profilerDataWithTotal || []);
        setProfiler((_) => profilerDataWithTotal || []);
      }
    );
    return () => {
      explainDataManager.removeEventListener("updateExplainData", eventListener);
    };
  }, []);
  const searchByField = React.useCallback(
    (fieldName) => {
      return (event) => {
        setProfiler((_) => {
          return defaultProfiler.filter((element) => {
            return element[fieldName].includes(event.target.value);
          });
        });
      };
    },
    [defaultProfiler]
  );
  const sort = React.useCallback((fieldName = "path") => {
    return (order) => {
      let localOrder = order;
      if (!order || order === 0) {
        return;
      } else if (order >= 1) {
        localOrder = 1;
      } else {
        localOrder = -1;
      }
      setProfiler((prevProfiler) => {
        return prevProfiler.slice().sort((a, b) => {
          return localOrder * `${a[fieldName]}`.localeCompare(`${b[fieldName]}`, void 0, {
            numeric: fieldName !== "path"
          });
        });
      });
    };
  }, []);
  const changePathOrder = React.useCallback(() => {
    if (pathOrder !== 0) {
      setPathOrder((prev) => -prev);
    } else {
      setPathOrder(1);
    }
    setTimeOrder(0);
    setTotalOrder(0);
  }, [pathOrder]);
  const changeTimeOrder = React.useCallback(() => {
    if (timeOrder !== 0) {
      setTimeOrder((prev) => -prev);
    } else {
      setTimeOrder(1);
    }
    setPathOrder(0);
    setTotalOrder(0);
  }, [timeOrder]);
  const changeTotalOrder = React.useCallback(() => {
    if (totalOrder !== 0) {
      setTotalOrder((prev) => -prev);
    } else {
      setTotalOrder(1);
    }
    setTimeOrder(0);
    setPathOrder(0);
  }, [totalOrder]);
  React.useEffect(() => {
    if (pathOrder) {
      const sortPath = sort("path");
      sortPath(pathOrder);
    }
  }, [pathOrder, sort]);
  React.useEffect(() => {
    if (timeOrder) {
      const sortTime = sort("time");
      sortTime(timeOrder);
    }
  }, [timeOrder, sort]);
  React.useEffect(() => {
    if (totalOrder) {
      const sortTotal = sort("totalTime");
      sortTotal(totalOrder);
    }
  }, [totalOrder, sort]);
  return {
    profiler,
    searchByPath: searchByField("path"),
    changePathOrder,
    changeTimeOrder,
    changeTotalOrder,
    timeOrder,
    pathOrder,
    totalOrder,
    limits
  };
}, "useProfiler");
const container$4 = "_container_1n71v_1";
const explainData$1 = "_explainData_1n71v_5";
const searchContainer$1 = "_searchContainer_1n71v_9";
const searchInput$1 = "_searchInput_1n71v_13";
const searchLabel$1 = "_searchLabel_1n71v_28";
const th$1 = "_th_1n71v_40";
const arrow$2 = "_arrow_1n71v_46";
const headerContainer = "_headerContainer_1n71v_51";
const chartIconContainer = "_chartIconContainer_1n71v_57";
const chartIcon = "_chartIcon_1n71v_57";
const rotate180$2 = "_rotate180_1n71v_71";
const thContent$1 = "_thContent_1n71v_75";
const justifyFlexStart$1 = "_justifyFlexStart_1n71v_80";
const justifyFlexEnd$1 = "_justifyFlexEnd_1n71v_84";
const tableCellAlignLeft$1 = "_tableCellAlignLeft_1n71v_88";
const tableCellAlignRight$1 = "_tableCellAlignRight_1n71v_92";
const styles$5 = {
  container: container$4,
  explainData: explainData$1,
  searchContainer: searchContainer$1,
  searchInput: searchInput$1,
  searchLabel: searchLabel$1,
  th: th$1,
  arrow: arrow$2,
  headerContainer,
  chartIconContainer,
  chartIcon,
  rotate180: rotate180$2,
  thContent: thContent$1,
  justifyFlexStart: justifyFlexStart$1,
  justifyFlexEnd: justifyFlexEnd$1,
  tableCellAlignLeft: tableCellAlignLeft$1,
  tableCellAlignRight: tableCellAlignRight$1
};
const modalWrapper = "_modalWrapper_hk2tr_1";
const container$3 = "_container_hk2tr_14";
const header$1 = "_header_hk2tr_25";
const closeButton = "_closeButton_hk2tr_30";
const styles$4 = {
  modalWrapper,
  container: container$3,
  header: header$1,
  closeButton
};
const Modal = /* @__PURE__ */ __name(({ isOpen, closeModal, children: children2 }) => {
  const modalRef = React__default.default.useRef(null);
  const handleClickOutside = /* @__PURE__ */ __name((e) => {
    if (modalRef.current && !modalRef.current.contains(e.target)) {
      closeModal();
    }
  }, "handleClickOutside");
  return isOpen ? /* @__PURE__ */ React__default.default.createElement("div", {
    className: styles$4.modalWrapper,
    onClick: handleClickOutside
  }, /* @__PURE__ */ React__default.default.createElement("div", {
    className: styles$4.container,
    ref: modalRef
  }, /* @__PURE__ */ React__default.default.createElement("div", {
    className: styles$4.header
  }, /* @__PURE__ */ React__default.default.createElement("button", {
    className: styles$4.closeButton,
    onClick: closeModal
  }, "Close")), /* @__PURE__ */ React__default.default.createElement("div", null, children2))) : null;
}, "Modal");
function ascending$1(a, b) {
  return a == null || b == null ? NaN : a < b ? -1 : a > b ? 1 : a >= b ? 0 : NaN;
}
__name(ascending$1, "ascending$1");
function descending(a, b) {
  return a == null || b == null ? NaN : b < a ? -1 : b > a ? 1 : b >= a ? 0 : NaN;
}
__name(descending, "descending");
function bisector(f) {
  let compare1, compare2, delta;
  if (f.length !== 2) {
    compare1 = ascending$1;
    compare2 = /* @__PURE__ */ __name((d, x) => ascending$1(f(d), x), "compare2");
    delta = /* @__PURE__ */ __name((d, x) => f(d) - x, "delta");
  } else {
    compare1 = f === ascending$1 || f === descending ? f : zero$1;
    compare2 = f;
    delta = f;
  }
  function left2(a, x, lo = 0, hi = a.length) {
    if (lo < hi) {
      if (compare1(x, x) !== 0)
        return hi;
      do {
        const mid = lo + hi >>> 1;
        if (compare2(a[mid], x) < 0)
          lo = mid + 1;
        else
          hi = mid;
      } while (lo < hi);
    }
    return lo;
  }
  __name(left2, "left");
  function right2(a, x, lo = 0, hi = a.length) {
    if (lo < hi) {
      if (compare1(x, x) !== 0)
        return hi;
      do {
        const mid = lo + hi >>> 1;
        if (compare2(a[mid], x) <= 0)
          lo = mid + 1;
        else
          hi = mid;
      } while (lo < hi);
    }
    return lo;
  }
  __name(right2, "right");
  function center2(a, x, lo = 0, hi = a.length) {
    const i = left2(a, x, lo, hi - 1);
    return i > lo && delta(a[i - 1], x) > -delta(a[i], x) ? i - 1 : i;
  }
  __name(center2, "center");
  return { left: left2, center: center2, right: right2 };
}
__name(bisector, "bisector");
function zero$1() {
  return 0;
}
__name(zero$1, "zero$1");
function number$2(x) {
  return x === null ? NaN : +x;
}
__name(number$2, "number$2");
const ascendingBisect = bisector(ascending$1);
const bisectRight = ascendingBisect.right;
bisector(number$2).center;
const bisect = bisectRight;
class InternMap extends Map {
  constructor(entries, key = keyof) {
    super();
    Object.defineProperties(this, { _intern: { value: /* @__PURE__ */ new Map() }, _key: { value: key } });
    if (entries != null)
      for (const [key2, value] of entries)
        this.set(key2, value);
  }
  get(key) {
    return super.get(intern_get(this, key));
  }
  has(key) {
    return super.has(intern_get(this, key));
  }
  set(key, value) {
    return super.set(intern_set(this, key), value);
  }
  delete(key) {
    return super.delete(intern_delete(this, key));
  }
}
__name(InternMap, "InternMap");
function intern_get({ _intern, _key }, value) {
  const key = _key(value);
  return _intern.has(key) ? _intern.get(key) : value;
}
__name(intern_get, "intern_get");
function intern_set({ _intern, _key }, value) {
  const key = _key(value);
  if (_intern.has(key))
    return _intern.get(key);
  _intern.set(key, value);
  return value;
}
__name(intern_set, "intern_set");
function intern_delete({ _intern, _key }, value) {
  const key = _key(value);
  if (_intern.has(key)) {
    value = _intern.get(key);
    _intern.delete(key);
  }
  return value;
}
__name(intern_delete, "intern_delete");
function keyof(value) {
  return value !== null && typeof value === "object" ? value.valueOf() : value;
}
__name(keyof, "keyof");
var e10 = Math.sqrt(50), e5 = Math.sqrt(10), e2 = Math.sqrt(2);
function ticks(start2, stop, count) {
  var reverse, i = -1, n, ticks2, step;
  stop = +stop, start2 = +start2, count = +count;
  if (start2 === stop && count > 0)
    return [start2];
  if (reverse = stop < start2)
    n = start2, start2 = stop, stop = n;
  if ((step = tickIncrement(start2, stop, count)) === 0 || !isFinite(step))
    return [];
  if (step > 0) {
    let r0 = Math.round(start2 / step), r1 = Math.round(stop / step);
    if (r0 * step < start2)
      ++r0;
    if (r1 * step > stop)
      --r1;
    ticks2 = new Array(n = r1 - r0 + 1);
    while (++i < n)
      ticks2[i] = (r0 + i) * step;
  } else {
    step = -step;
    let r0 = Math.round(start2 * step), r1 = Math.round(stop * step);
    if (r0 / step < start2)
      ++r0;
    if (r1 / step > stop)
      --r1;
    ticks2 = new Array(n = r1 - r0 + 1);
    while (++i < n)
      ticks2[i] = (r0 + i) / step;
  }
  if (reverse)
    ticks2.reverse();
  return ticks2;
}
__name(ticks, "ticks");
function tickIncrement(start2, stop, count) {
  var step = (stop - start2) / Math.max(0, count), power = Math.floor(Math.log(step) / Math.LN10), error = step / Math.pow(10, power);
  return power >= 0 ? (error >= e10 ? 10 : error >= e5 ? 5 : error >= e2 ? 2 : 1) * Math.pow(10, power) : -Math.pow(10, -power) / (error >= e10 ? 10 : error >= e5 ? 5 : error >= e2 ? 2 : 1);
}
__name(tickIncrement, "tickIncrement");
function tickStep(start2, stop, count) {
  var step0 = Math.abs(stop - start2) / Math.max(0, count), step1 = Math.pow(10, Math.floor(Math.log(step0) / Math.LN10)), error = step0 / step1;
  if (error >= e10)
    step1 *= 10;
  else if (error >= e5)
    step1 *= 5;
  else if (error >= e2)
    step1 *= 2;
  return stop < start2 ? -step1 : step1;
}
__name(tickStep, "tickStep");
function range(start2, stop, step) {
  start2 = +start2, stop = +stop, step = (n = arguments.length) < 2 ? (stop = start2, start2 = 0, 1) : n < 3 ? 1 : +step;
  var i = -1, n = Math.max(0, Math.ceil((stop - start2) / step)) | 0, range2 = new Array(n);
  while (++i < n) {
    range2[i] = start2 + i * step;
  }
  return range2;
}
__name(range, "range");
function identity$3(x) {
  return x;
}
__name(identity$3, "identity$3");
var top = 1, right = 2, bottom = 3, left = 4, epsilon = 1e-6;
function translateX(x) {
  return "translate(" + x + ",0)";
}
__name(translateX, "translateX");
function translateY(y) {
  return "translate(0," + y + ")";
}
__name(translateY, "translateY");
function number$1(scale) {
  return (d) => +scale(d);
}
__name(number$1, "number$1");
function center(scale, offset) {
  offset = Math.max(0, scale.bandwidth() - offset * 2) / 2;
  if (scale.round())
    offset = Math.round(offset);
  return (d) => +scale(d) + offset;
}
__name(center, "center");
function entering() {
  return !this.__axis;
}
__name(entering, "entering");
function axis(orient, scale) {
  var tickArguments = [], tickValues = null, tickFormat2 = null, tickSizeInner = 6, tickSizeOuter = 6, tickPadding = 3, offset = typeof window !== "undefined" && window.devicePixelRatio > 1 ? 0 : 0.5, k = orient === top || orient === left ? -1 : 1, x = orient === left || orient === right ? "x" : "y", transform = orient === top || orient === bottom ? translateX : translateY;
  function axis2(context) {
    var values = tickValues == null ? scale.ticks ? scale.ticks.apply(scale, tickArguments) : scale.domain() : tickValues, format2 = tickFormat2 == null ? scale.tickFormat ? scale.tickFormat.apply(scale, tickArguments) : identity$3 : tickFormat2, spacing = Math.max(tickSizeInner, 0) + tickPadding, range2 = scale.range(), range0 = +range2[0] + offset, range1 = +range2[range2.length - 1] + offset, position = (scale.bandwidth ? center : number$1)(scale.copy(), offset), selection2 = context.selection ? context.selection() : context, path = selection2.selectAll(".domain").data([null]), tick = selection2.selectAll(".tick").data(values, scale).order(), tickExit = tick.exit(), tickEnter = tick.enter().append("g").attr("class", "tick"), line = tick.select("line"), text = tick.select("text");
    path = path.merge(path.enter().insert("path", ".tick").attr("class", "domain").attr("stroke", "currentColor"));
    tick = tick.merge(tickEnter);
    line = line.merge(tickEnter.append("line").attr("stroke", "currentColor").attr(x + "2", k * tickSizeInner));
    text = text.merge(tickEnter.append("text").attr("fill", "currentColor").attr(x, k * spacing).attr("dy", orient === top ? "0em" : orient === bottom ? "0.71em" : "0.32em"));
    if (context !== selection2) {
      path = path.transition(context);
      tick = tick.transition(context);
      line = line.transition(context);
      text = text.transition(context);
      tickExit = tickExit.transition(context).attr("opacity", epsilon).attr("transform", function(d) {
        return isFinite(d = position(d)) ? transform(d + offset) : this.getAttribute("transform");
      });
      tickEnter.attr("opacity", epsilon).attr("transform", function(d) {
        var p = this.parentNode.__axis;
        return transform((p && isFinite(p = p(d)) ? p : position(d)) + offset);
      });
    }
    tickExit.remove();
    path.attr("d", orient === left || orient === right ? tickSizeOuter ? "M" + k * tickSizeOuter + "," + range0 + "H" + offset + "V" + range1 + "H" + k * tickSizeOuter : "M" + offset + "," + range0 + "V" + range1 : tickSizeOuter ? "M" + range0 + "," + k * tickSizeOuter + "V" + offset + "H" + range1 + "V" + k * tickSizeOuter : "M" + range0 + "," + offset + "H" + range1);
    tick.attr("opacity", 1).attr("transform", function(d) {
      return transform(position(d) + offset);
    });
    line.attr(x + "2", k * tickSizeInner);
    text.attr(x, k * spacing).text(format2);
    selection2.filter(entering).attr("fill", "none").attr("font-size", 10).attr("font-family", "sans-serif").attr("text-anchor", orient === right ? "start" : orient === left ? "end" : "middle");
    selection2.each(function() {
      this.__axis = position;
    });
  }
  __name(axis2, "axis");
  axis2.scale = function(_) {
    return arguments.length ? (scale = _, axis2) : scale;
  };
  axis2.ticks = function() {
    return tickArguments = Array.from(arguments), axis2;
  };
  axis2.tickArguments = function(_) {
    return arguments.length ? (tickArguments = _ == null ? [] : Array.from(_), axis2) : tickArguments.slice();
  };
  axis2.tickValues = function(_) {
    return arguments.length ? (tickValues = _ == null ? null : Array.from(_), axis2) : tickValues && tickValues.slice();
  };
  axis2.tickFormat = function(_) {
    return arguments.length ? (tickFormat2 = _, axis2) : tickFormat2;
  };
  axis2.tickSize = function(_) {
    return arguments.length ? (tickSizeInner = tickSizeOuter = +_, axis2) : tickSizeInner;
  };
  axis2.tickSizeInner = function(_) {
    return arguments.length ? (tickSizeInner = +_, axis2) : tickSizeInner;
  };
  axis2.tickSizeOuter = function(_) {
    return arguments.length ? (tickSizeOuter = +_, axis2) : tickSizeOuter;
  };
  axis2.tickPadding = function(_) {
    return arguments.length ? (tickPadding = +_, axis2) : tickPadding;
  };
  axis2.offset = function(_) {
    return arguments.length ? (offset = +_, axis2) : offset;
  };
  return axis2;
}
__name(axis, "axis");
function axisTop(scale) {
  return axis(top, scale);
}
__name(axisTop, "axisTop");
function axisLeft(scale) {
  return axis(left, scale);
}
__name(axisLeft, "axisLeft");
var noop = { value: () => {
} };
function dispatch() {
  for (var i = 0, n = arguments.length, _ = {}, t; i < n; ++i) {
    if (!(t = arguments[i] + "") || t in _ || /[\s.]/.test(t))
      throw new Error("illegal type: " + t);
    _[t] = [];
  }
  return new Dispatch(_);
}
__name(dispatch, "dispatch");
function Dispatch(_) {
  this._ = _;
}
__name(Dispatch, "Dispatch");
function parseTypenames$1(typenames, types) {
  return typenames.trim().split(/^|\s+/).map(function(t) {
    var name = "", i = t.indexOf(".");
    if (i >= 0)
      name = t.slice(i + 1), t = t.slice(0, i);
    if (t && !types.hasOwnProperty(t))
      throw new Error("unknown type: " + t);
    return { type: t, name };
  });
}
__name(parseTypenames$1, "parseTypenames$1");
Dispatch.prototype = dispatch.prototype = {
  constructor: Dispatch,
  on: function(typename, callback) {
    var _ = this._, T = parseTypenames$1(typename + "", _), t, i = -1, n = T.length;
    if (arguments.length < 2) {
      while (++i < n)
        if ((t = (typename = T[i]).type) && (t = get$1(_[t], typename.name)))
          return t;
      return;
    }
    if (callback != null && typeof callback !== "function")
      throw new Error("invalid callback: " + callback);
    while (++i < n) {
      if (t = (typename = T[i]).type)
        _[t] = set$1(_[t], typename.name, callback);
      else if (callback == null)
        for (t in _)
          _[t] = set$1(_[t], typename.name, null);
    }
    return this;
  },
  copy: function() {
    var copy2 = {}, _ = this._;
    for (var t in _)
      copy2[t] = _[t].slice();
    return new Dispatch(copy2);
  },
  call: function(type, that) {
    if ((n = arguments.length - 2) > 0)
      for (var args = new Array(n), i = 0, n, t; i < n; ++i)
        args[i] = arguments[i + 2];
    if (!this._.hasOwnProperty(type))
      throw new Error("unknown type: " + type);
    for (t = this._[type], i = 0, n = t.length; i < n; ++i)
      t[i].value.apply(that, args);
  },
  apply: function(type, that, args) {
    if (!this._.hasOwnProperty(type))
      throw new Error("unknown type: " + type);
    for (var t = this._[type], i = 0, n = t.length; i < n; ++i)
      t[i].value.apply(that, args);
  }
};
function get$1(type, name) {
  for (var i = 0, n = type.length, c; i < n; ++i) {
    if ((c = type[i]).name === name) {
      return c.value;
    }
  }
}
__name(get$1, "get$1");
function set$1(type, name, callback) {
  for (var i = 0, n = type.length; i < n; ++i) {
    if (type[i].name === name) {
      type[i] = noop, type = type.slice(0, i).concat(type.slice(i + 1));
      break;
    }
  }
  if (callback != null)
    type.push({ name, value: callback });
  return type;
}
__name(set$1, "set$1");
var xhtml = "http://www.w3.org/1999/xhtml";
const namespaces = {
  svg: "http://www.w3.org/2000/svg",
  xhtml,
  xlink: "http://www.w3.org/1999/xlink",
  xml: "http://www.w3.org/XML/1998/namespace",
  xmlns: "http://www.w3.org/2000/xmlns/"
};
function namespace(name) {
  var prefix = name += "", i = prefix.indexOf(":");
  if (i >= 0 && (prefix = name.slice(0, i)) !== "xmlns")
    name = name.slice(i + 1);
  return namespaces.hasOwnProperty(prefix) ? { space: namespaces[prefix], local: name } : name;
}
__name(namespace, "namespace");
function creatorInherit(name) {
  return function() {
    var document2 = this.ownerDocument, uri = this.namespaceURI;
    return uri === xhtml && document2.documentElement.namespaceURI === xhtml ? document2.createElement(name) : document2.createElementNS(uri, name);
  };
}
__name(creatorInherit, "creatorInherit");
function creatorFixed(fullname) {
  return function() {
    return this.ownerDocument.createElementNS(fullname.space, fullname.local);
  };
}
__name(creatorFixed, "creatorFixed");
function creator(name) {
  var fullname = namespace(name);
  return (fullname.local ? creatorFixed : creatorInherit)(fullname);
}
__name(creator, "creator");
function none$2() {
}
__name(none$2, "none$2");
function selector(selector2) {
  return selector2 == null ? none$2 : function() {
    return this.querySelector(selector2);
  };
}
__name(selector, "selector");
function selection_select(select2) {
  if (typeof select2 !== "function")
    select2 = selector(select2);
  for (var groups = this._groups, m = groups.length, subgroups = new Array(m), j = 0; j < m; ++j) {
    for (var group = groups[j], n = group.length, subgroup = subgroups[j] = new Array(n), node, subnode, i = 0; i < n; ++i) {
      if ((node = group[i]) && (subnode = select2.call(node, node.__data__, i, group))) {
        if ("__data__" in node)
          subnode.__data__ = node.__data__;
        subgroup[i] = subnode;
      }
    }
  }
  return new Selection$1(subgroups, this._parents);
}
__name(selection_select, "selection_select");
function array$1(x) {
  return x == null ? [] : Array.isArray(x) ? x : Array.from(x);
}
__name(array$1, "array$1");
function empty() {
  return [];
}
__name(empty, "empty");
function selectorAll(selector2) {
  return selector2 == null ? empty : function() {
    return this.querySelectorAll(selector2);
  };
}
__name(selectorAll, "selectorAll");
function arrayAll(select2) {
  return function() {
    return array$1(select2.apply(this, arguments));
  };
}
__name(arrayAll, "arrayAll");
function selection_selectAll(select2) {
  if (typeof select2 === "function")
    select2 = arrayAll(select2);
  else
    select2 = selectorAll(select2);
  for (var groups = this._groups, m = groups.length, subgroups = [], parents = [], j = 0; j < m; ++j) {
    for (var group = groups[j], n = group.length, node, i = 0; i < n; ++i) {
      if (node = group[i]) {
        subgroups.push(select2.call(node, node.__data__, i, group));
        parents.push(node);
      }
    }
  }
  return new Selection$1(subgroups, parents);
}
__name(selection_selectAll, "selection_selectAll");
function matcher(selector2) {
  return function() {
    return this.matches(selector2);
  };
}
__name(matcher, "matcher");
function childMatcher(selector2) {
  return function(node) {
    return node.matches(selector2);
  };
}
__name(childMatcher, "childMatcher");
var find = Array.prototype.find;
function childFind(match) {
  return function() {
    return find.call(this.children, match);
  };
}
__name(childFind, "childFind");
function childFirst() {
  return this.firstElementChild;
}
__name(childFirst, "childFirst");
function selection_selectChild(match) {
  return this.select(match == null ? childFirst : childFind(typeof match === "function" ? match : childMatcher(match)));
}
__name(selection_selectChild, "selection_selectChild");
var filter = Array.prototype.filter;
function children() {
  return Array.from(this.children);
}
__name(children, "children");
function childrenFilter(match) {
  return function() {
    return filter.call(this.children, match);
  };
}
__name(childrenFilter, "childrenFilter");
function selection_selectChildren(match) {
  return this.selectAll(match == null ? children : childrenFilter(typeof match === "function" ? match : childMatcher(match)));
}
__name(selection_selectChildren, "selection_selectChildren");
function selection_filter(match) {
  if (typeof match !== "function")
    match = matcher(match);
  for (var groups = this._groups, m = groups.length, subgroups = new Array(m), j = 0; j < m; ++j) {
    for (var group = groups[j], n = group.length, subgroup = subgroups[j] = [], node, i = 0; i < n; ++i) {
      if ((node = group[i]) && match.call(node, node.__data__, i, group)) {
        subgroup.push(node);
      }
    }
  }
  return new Selection$1(subgroups, this._parents);
}
__name(selection_filter, "selection_filter");
function sparse(update) {
  return new Array(update.length);
}
__name(sparse, "sparse");
function selection_enter() {
  return new Selection$1(this._enter || this._groups.map(sparse), this._parents);
}
__name(selection_enter, "selection_enter");
function EnterNode(parent, datum2) {
  this.ownerDocument = parent.ownerDocument;
  this.namespaceURI = parent.namespaceURI;
  this._next = null;
  this._parent = parent;
  this.__data__ = datum2;
}
__name(EnterNode, "EnterNode");
EnterNode.prototype = {
  constructor: EnterNode,
  appendChild: function(child) {
    return this._parent.insertBefore(child, this._next);
  },
  insertBefore: function(child, next) {
    return this._parent.insertBefore(child, next);
  },
  querySelector: function(selector2) {
    return this._parent.querySelector(selector2);
  },
  querySelectorAll: function(selector2) {
    return this._parent.querySelectorAll(selector2);
  }
};
function constant$2(x) {
  return function() {
    return x;
  };
}
__name(constant$2, "constant$2");
function bindIndex(parent, group, enter, update, exit, data) {
  var i = 0, node, groupLength = group.length, dataLength = data.length;
  for (; i < dataLength; ++i) {
    if (node = group[i]) {
      node.__data__ = data[i];
      update[i] = node;
    } else {
      enter[i] = new EnterNode(parent, data[i]);
    }
  }
  for (; i < groupLength; ++i) {
    if (node = group[i]) {
      exit[i] = node;
    }
  }
}
__name(bindIndex, "bindIndex");
function bindKey(parent, group, enter, update, exit, data, key) {
  var i, node, nodeByKeyValue = /* @__PURE__ */ new Map(), groupLength = group.length, dataLength = data.length, keyValues = new Array(groupLength), keyValue;
  for (i = 0; i < groupLength; ++i) {
    if (node = group[i]) {
      keyValues[i] = keyValue = key.call(node, node.__data__, i, group) + "";
      if (nodeByKeyValue.has(keyValue)) {
        exit[i] = node;
      } else {
        nodeByKeyValue.set(keyValue, node);
      }
    }
  }
  for (i = 0; i < dataLength; ++i) {
    keyValue = key.call(parent, data[i], i, data) + "";
    if (node = nodeByKeyValue.get(keyValue)) {
      update[i] = node;
      node.__data__ = data[i];
      nodeByKeyValue.delete(keyValue);
    } else {
      enter[i] = new EnterNode(parent, data[i]);
    }
  }
  for (i = 0; i < groupLength; ++i) {
    if ((node = group[i]) && nodeByKeyValue.get(keyValues[i]) === node) {
      exit[i] = node;
    }
  }
}
__name(bindKey, "bindKey");
function datum(node) {
  return node.__data__;
}
__name(datum, "datum");
function selection_data(value, key) {
  if (!arguments.length)
    return Array.from(this, datum);
  var bind = key ? bindKey : bindIndex, parents = this._parents, groups = this._groups;
  if (typeof value !== "function")
    value = constant$2(value);
  for (var m = groups.length, update = new Array(m), enter = new Array(m), exit = new Array(m), j = 0; j < m; ++j) {
    var parent = parents[j], group = groups[j], groupLength = group.length, data = arraylike(value.call(parent, parent && parent.__data__, j, parents)), dataLength = data.length, enterGroup = enter[j] = new Array(dataLength), updateGroup = update[j] = new Array(dataLength), exitGroup = exit[j] = new Array(groupLength);
    bind(parent, group, enterGroup, updateGroup, exitGroup, data, key);
    for (var i0 = 0, i1 = 0, previous, next; i0 < dataLength; ++i0) {
      if (previous = enterGroup[i0]) {
        if (i0 >= i1)
          i1 = i0 + 1;
        while (!(next = updateGroup[i1]) && ++i1 < dataLength)
          ;
        previous._next = next || null;
      }
    }
  }
  update = new Selection$1(update, parents);
  update._enter = enter;
  update._exit = exit;
  return update;
}
__name(selection_data, "selection_data");
function arraylike(data) {
  return typeof data === "object" && "length" in data ? data : Array.from(data);
}
__name(arraylike, "arraylike");
function selection_exit() {
  return new Selection$1(this._exit || this._groups.map(sparse), this._parents);
}
__name(selection_exit, "selection_exit");
function selection_join(onenter, onupdate, onexit) {
  var enter = this.enter(), update = this, exit = this.exit();
  if (typeof onenter === "function") {
    enter = onenter(enter);
    if (enter)
      enter = enter.selection();
  } else {
    enter = enter.append(onenter + "");
  }
  if (onupdate != null) {
    update = onupdate(update);
    if (update)
      update = update.selection();
  }
  if (onexit == null)
    exit.remove();
  else
    onexit(exit);
  return enter && update ? enter.merge(update).order() : update;
}
__name(selection_join, "selection_join");
function selection_merge(context) {
  var selection2 = context.selection ? context.selection() : context;
  for (var groups0 = this._groups, groups1 = selection2._groups, m0 = groups0.length, m1 = groups1.length, m = Math.min(m0, m1), merges = new Array(m0), j = 0; j < m; ++j) {
    for (var group0 = groups0[j], group1 = groups1[j], n = group0.length, merge = merges[j] = new Array(n), node, i = 0; i < n; ++i) {
      if (node = group0[i] || group1[i]) {
        merge[i] = node;
      }
    }
  }
  for (; j < m0; ++j) {
    merges[j] = groups0[j];
  }
  return new Selection$1(merges, this._parents);
}
__name(selection_merge, "selection_merge");
function selection_order() {
  for (var groups = this._groups, j = -1, m = groups.length; ++j < m; ) {
    for (var group = groups[j], i = group.length - 1, next = group[i], node; --i >= 0; ) {
      if (node = group[i]) {
        if (next && node.compareDocumentPosition(next) ^ 4)
          next.parentNode.insertBefore(node, next);
        next = node;
      }
    }
  }
  return this;
}
__name(selection_order, "selection_order");
function selection_sort(compare) {
  if (!compare)
    compare = ascending;
  function compareNode(a, b) {
    return a && b ? compare(a.__data__, b.__data__) : !a - !b;
  }
  __name(compareNode, "compareNode");
  for (var groups = this._groups, m = groups.length, sortgroups = new Array(m), j = 0; j < m; ++j) {
    for (var group = groups[j], n = group.length, sortgroup = sortgroups[j] = new Array(n), node, i = 0; i < n; ++i) {
      if (node = group[i]) {
        sortgroup[i] = node;
      }
    }
    sortgroup.sort(compareNode);
  }
  return new Selection$1(sortgroups, this._parents).order();
}
__name(selection_sort, "selection_sort");
function ascending(a, b) {
  return a < b ? -1 : a > b ? 1 : a >= b ? 0 : NaN;
}
__name(ascending, "ascending");
function selection_call() {
  var callback = arguments[0];
  arguments[0] = this;
  callback.apply(null, arguments);
  return this;
}
__name(selection_call, "selection_call");
function selection_nodes() {
  return Array.from(this);
}
__name(selection_nodes, "selection_nodes");
function selection_node() {
  for (var groups = this._groups, j = 0, m = groups.length; j < m; ++j) {
    for (var group = groups[j], i = 0, n = group.length; i < n; ++i) {
      var node = group[i];
      if (node)
        return node;
    }
  }
  return null;
}
__name(selection_node, "selection_node");
function selection_size() {
  let size = 0;
  for (const node of this)
    ++size;
  return size;
}
__name(selection_size, "selection_size");
function selection_empty() {
  return !this.node();
}
__name(selection_empty, "selection_empty");
function selection_each(callback) {
  for (var groups = this._groups, j = 0, m = groups.length; j < m; ++j) {
    for (var group = groups[j], i = 0, n = group.length, node; i < n; ++i) {
      if (node = group[i])
        callback.call(node, node.__data__, i, group);
    }
  }
  return this;
}
__name(selection_each, "selection_each");
function attrRemove$1(name) {
  return function() {
    this.removeAttribute(name);
  };
}
__name(attrRemove$1, "attrRemove$1");
function attrRemoveNS$1(fullname) {
  return function() {
    this.removeAttributeNS(fullname.space, fullname.local);
  };
}
__name(attrRemoveNS$1, "attrRemoveNS$1");
function attrConstant$1(name, value) {
  return function() {
    this.setAttribute(name, value);
  };
}
__name(attrConstant$1, "attrConstant$1");
function attrConstantNS$1(fullname, value) {
  return function() {
    this.setAttributeNS(fullname.space, fullname.local, value);
  };
}
__name(attrConstantNS$1, "attrConstantNS$1");
function attrFunction$1(name, value) {
  return function() {
    var v = value.apply(this, arguments);
    if (v == null)
      this.removeAttribute(name);
    else
      this.setAttribute(name, v);
  };
}
__name(attrFunction$1, "attrFunction$1");
function attrFunctionNS$1(fullname, value) {
  return function() {
    var v = value.apply(this, arguments);
    if (v == null)
      this.removeAttributeNS(fullname.space, fullname.local);
    else
      this.setAttributeNS(fullname.space, fullname.local, v);
  };
}
__name(attrFunctionNS$1, "attrFunctionNS$1");
function selection_attr(name, value) {
  var fullname = namespace(name);
  if (arguments.length < 2) {
    var node = this.node();
    return fullname.local ? node.getAttributeNS(fullname.space, fullname.local) : node.getAttribute(fullname);
  }
  return this.each((value == null ? fullname.local ? attrRemoveNS$1 : attrRemove$1 : typeof value === "function" ? fullname.local ? attrFunctionNS$1 : attrFunction$1 : fullname.local ? attrConstantNS$1 : attrConstant$1)(fullname, value));
}
__name(selection_attr, "selection_attr");
function defaultView(node) {
  return node.ownerDocument && node.ownerDocument.defaultView || node.document && node || node.defaultView;
}
__name(defaultView, "defaultView");
function styleRemove$1(name) {
  return function() {
    this.style.removeProperty(name);
  };
}
__name(styleRemove$1, "styleRemove$1");
function styleConstant$1(name, value, priority) {
  return function() {
    this.style.setProperty(name, value, priority);
  };
}
__name(styleConstant$1, "styleConstant$1");
function styleFunction$1(name, value, priority) {
  return function() {
    var v = value.apply(this, arguments);
    if (v == null)
      this.style.removeProperty(name);
    else
      this.style.setProperty(name, v, priority);
  };
}
__name(styleFunction$1, "styleFunction$1");
function selection_style(name, value, priority) {
  return arguments.length > 1 ? this.each((value == null ? styleRemove$1 : typeof value === "function" ? styleFunction$1 : styleConstant$1)(name, value, priority == null ? "" : priority)) : styleValue(this.node(), name);
}
__name(selection_style, "selection_style");
function styleValue(node, name) {
  return node.style.getPropertyValue(name) || defaultView(node).getComputedStyle(node, null).getPropertyValue(name);
}
__name(styleValue, "styleValue");
function propertyRemove(name) {
  return function() {
    delete this[name];
  };
}
__name(propertyRemove, "propertyRemove");
function propertyConstant(name, value) {
  return function() {
    this[name] = value;
  };
}
__name(propertyConstant, "propertyConstant");
function propertyFunction(name, value) {
  return function() {
    var v = value.apply(this, arguments);
    if (v == null)
      delete this[name];
    else
      this[name] = v;
  };
}
__name(propertyFunction, "propertyFunction");
function selection_property(name, value) {
  return arguments.length > 1 ? this.each((value == null ? propertyRemove : typeof value === "function" ? propertyFunction : propertyConstant)(name, value)) : this.node()[name];
}
__name(selection_property, "selection_property");
function classArray(string) {
  return string.trim().split(/^|\s+/);
}
__name(classArray, "classArray");
function classList(node) {
  return node.classList || new ClassList(node);
}
__name(classList, "classList");
function ClassList(node) {
  this._node = node;
  this._names = classArray(node.getAttribute("class") || "");
}
__name(ClassList, "ClassList");
ClassList.prototype = {
  add: function(name) {
    var i = this._names.indexOf(name);
    if (i < 0) {
      this._names.push(name);
      this._node.setAttribute("class", this._names.join(" "));
    }
  },
  remove: function(name) {
    var i = this._names.indexOf(name);
    if (i >= 0) {
      this._names.splice(i, 1);
      this._node.setAttribute("class", this._names.join(" "));
    }
  },
  contains: function(name) {
    return this._names.indexOf(name) >= 0;
  }
};
function classedAdd(node, names) {
  var list = classList(node), i = -1, n = names.length;
  while (++i < n)
    list.add(names[i]);
}
__name(classedAdd, "classedAdd");
function classedRemove(node, names) {
  var list = classList(node), i = -1, n = names.length;
  while (++i < n)
    list.remove(names[i]);
}
__name(classedRemove, "classedRemove");
function classedTrue(names) {
  return function() {
    classedAdd(this, names);
  };
}
__name(classedTrue, "classedTrue");
function classedFalse(names) {
  return function() {
    classedRemove(this, names);
  };
}
__name(classedFalse, "classedFalse");
function classedFunction(names, value) {
  return function() {
    (value.apply(this, arguments) ? classedAdd : classedRemove)(this, names);
  };
}
__name(classedFunction, "classedFunction");
function selection_classed(name, value) {
  var names = classArray(name + "");
  if (arguments.length < 2) {
    var list = classList(this.node()), i = -1, n = names.length;
    while (++i < n)
      if (!list.contains(names[i]))
        return false;
    return true;
  }
  return this.each((typeof value === "function" ? classedFunction : value ? classedTrue : classedFalse)(names, value));
}
__name(selection_classed, "selection_classed");
function textRemove() {
  this.textContent = "";
}
__name(textRemove, "textRemove");
function textConstant$1(value) {
  return function() {
    this.textContent = value;
  };
}
__name(textConstant$1, "textConstant$1");
function textFunction$1(value) {
  return function() {
    var v = value.apply(this, arguments);
    this.textContent = v == null ? "" : v;
  };
}
__name(textFunction$1, "textFunction$1");
function selection_text(value) {
  return arguments.length ? this.each(value == null ? textRemove : (typeof value === "function" ? textFunction$1 : textConstant$1)(value)) : this.node().textContent;
}
__name(selection_text, "selection_text");
function htmlRemove() {
  this.innerHTML = "";
}
__name(htmlRemove, "htmlRemove");
function htmlConstant(value) {
  return function() {
    this.innerHTML = value;
  };
}
__name(htmlConstant, "htmlConstant");
function htmlFunction(value) {
  return function() {
    var v = value.apply(this, arguments);
    this.innerHTML = v == null ? "" : v;
  };
}
__name(htmlFunction, "htmlFunction");
function selection_html(value) {
  return arguments.length ? this.each(value == null ? htmlRemove : (typeof value === "function" ? htmlFunction : htmlConstant)(value)) : this.node().innerHTML;
}
__name(selection_html, "selection_html");
function raise() {
  if (this.nextSibling)
    this.parentNode.appendChild(this);
}
__name(raise, "raise");
function selection_raise() {
  return this.each(raise);
}
__name(selection_raise, "selection_raise");
function lower() {
  if (this.previousSibling)
    this.parentNode.insertBefore(this, this.parentNode.firstChild);
}
__name(lower, "lower");
function selection_lower() {
  return this.each(lower);
}
__name(selection_lower, "selection_lower");
function selection_append(name) {
  var create2 = typeof name === "function" ? name : creator(name);
  return this.select(function() {
    return this.appendChild(create2.apply(this, arguments));
  });
}
__name(selection_append, "selection_append");
function constantNull() {
  return null;
}
__name(constantNull, "constantNull");
function selection_insert(name, before) {
  var create2 = typeof name === "function" ? name : creator(name), select2 = before == null ? constantNull : typeof before === "function" ? before : selector(before);
  return this.select(function() {
    return this.insertBefore(create2.apply(this, arguments), select2.apply(this, arguments) || null);
  });
}
__name(selection_insert, "selection_insert");
function remove() {
  var parent = this.parentNode;
  if (parent)
    parent.removeChild(this);
}
__name(remove, "remove");
function selection_remove() {
  return this.each(remove);
}
__name(selection_remove, "selection_remove");
function selection_cloneShallow() {
  var clone = this.cloneNode(false), parent = this.parentNode;
  return parent ? parent.insertBefore(clone, this.nextSibling) : clone;
}
__name(selection_cloneShallow, "selection_cloneShallow");
function selection_cloneDeep() {
  var clone = this.cloneNode(true), parent = this.parentNode;
  return parent ? parent.insertBefore(clone, this.nextSibling) : clone;
}
__name(selection_cloneDeep, "selection_cloneDeep");
function selection_clone(deep) {
  return this.select(deep ? selection_cloneDeep : selection_cloneShallow);
}
__name(selection_clone, "selection_clone");
function selection_datum(value) {
  return arguments.length ? this.property("__data__", value) : this.node().__data__;
}
__name(selection_datum, "selection_datum");
function contextListener(listener) {
  return function(event) {
    listener.call(this, event, this.__data__);
  };
}
__name(contextListener, "contextListener");
function parseTypenames(typenames) {
  return typenames.trim().split(/^|\s+/).map(function(t) {
    var name = "", i = t.indexOf(".");
    if (i >= 0)
      name = t.slice(i + 1), t = t.slice(0, i);
    return { type: t, name };
  });
}
__name(parseTypenames, "parseTypenames");
function onRemove(typename) {
  return function() {
    var on = this.__on;
    if (!on)
      return;
    for (var j = 0, i = -1, m = on.length, o; j < m; ++j) {
      if (o = on[j], (!typename.type || o.type === typename.type) && o.name === typename.name) {
        this.removeEventListener(o.type, o.listener, o.options);
      } else {
        on[++i] = o;
      }
    }
    if (++i)
      on.length = i;
    else
      delete this.__on;
  };
}
__name(onRemove, "onRemove");
function onAdd(typename, value, options) {
  return function() {
    var on = this.__on, o, listener = contextListener(value);
    if (on)
      for (var j = 0, m = on.length; j < m; ++j) {
        if ((o = on[j]).type === typename.type && o.name === typename.name) {
          this.removeEventListener(o.type, o.listener, o.options);
          this.addEventListener(o.type, o.listener = listener, o.options = options);
          o.value = value;
          return;
        }
      }
    this.addEventListener(typename.type, listener, options);
    o = { type: typename.type, name: typename.name, value, listener, options };
    if (!on)
      this.__on = [o];
    else
      on.push(o);
  };
}
__name(onAdd, "onAdd");
function selection_on(typename, value, options) {
  var typenames = parseTypenames(typename + ""), i, n = typenames.length, t;
  if (arguments.length < 2) {
    var on = this.node().__on;
    if (on)
      for (var j = 0, m = on.length, o; j < m; ++j) {
        for (i = 0, o = on[j]; i < n; ++i) {
          if ((t = typenames[i]).type === o.type && t.name === o.name) {
            return o.value;
          }
        }
      }
    return;
  }
  on = value ? onAdd : onRemove;
  for (i = 0; i < n; ++i)
    this.each(on(typenames[i], value, options));
  return this;
}
__name(selection_on, "selection_on");
function dispatchEvent(node, type, params) {
  var window2 = defaultView(node), event = window2.CustomEvent;
  if (typeof event === "function") {
    event = new event(type, params);
  } else {
    event = window2.document.createEvent("Event");
    if (params)
      event.initEvent(type, params.bubbles, params.cancelable), event.detail = params.detail;
    else
      event.initEvent(type, false, false);
  }
  node.dispatchEvent(event);
}
__name(dispatchEvent, "dispatchEvent");
function dispatchConstant(type, params) {
  return function() {
    return dispatchEvent(this, type, params);
  };
}
__name(dispatchConstant, "dispatchConstant");
function dispatchFunction(type, params) {
  return function() {
    return dispatchEvent(this, type, params.apply(this, arguments));
  };
}
__name(dispatchFunction, "dispatchFunction");
function selection_dispatch(type, params) {
  return this.each((typeof params === "function" ? dispatchFunction : dispatchConstant)(type, params));
}
__name(selection_dispatch, "selection_dispatch");
function* selection_iterator() {
  for (var groups = this._groups, j = 0, m = groups.length; j < m; ++j) {
    for (var group = groups[j], i = 0, n = group.length, node; i < n; ++i) {
      if (node = group[i])
        yield node;
    }
  }
}
__name(selection_iterator, "selection_iterator");
var root = [null];
function Selection$1(groups, parents) {
  this._groups = groups;
  this._parents = parents;
}
__name(Selection$1, "Selection$1");
function selection() {
  return new Selection$1([[document.documentElement]], root);
}
__name(selection, "selection");
function selection_selection() {
  return this;
}
__name(selection_selection, "selection_selection");
Selection$1.prototype = selection.prototype = {
  constructor: Selection$1,
  select: selection_select,
  selectAll: selection_selectAll,
  selectChild: selection_selectChild,
  selectChildren: selection_selectChildren,
  filter: selection_filter,
  data: selection_data,
  enter: selection_enter,
  exit: selection_exit,
  join: selection_join,
  merge: selection_merge,
  selection: selection_selection,
  order: selection_order,
  sort: selection_sort,
  call: selection_call,
  nodes: selection_nodes,
  node: selection_node,
  size: selection_size,
  empty: selection_empty,
  each: selection_each,
  attr: selection_attr,
  style: selection_style,
  property: selection_property,
  classed: selection_classed,
  text: selection_text,
  html: selection_html,
  raise: selection_raise,
  lower: selection_lower,
  append: selection_append,
  insert: selection_insert,
  remove: selection_remove,
  clone: selection_clone,
  datum: selection_datum,
  on: selection_on,
  dispatch: selection_dispatch,
  [Symbol.iterator]: selection_iterator
};
function select(selector2) {
  return typeof selector2 === "string" ? new Selection$1([[document.querySelector(selector2)]], [document.documentElement]) : new Selection$1([[selector2]], root);
}
__name(select, "select");
function define(constructor, factory, prototype) {
  constructor.prototype = factory.prototype = prototype;
  prototype.constructor = constructor;
}
__name(define, "define");
function extend(parent, definition) {
  var prototype = Object.create(parent.prototype);
  for (var key in definition)
    prototype[key] = definition[key];
  return prototype;
}
__name(extend, "extend");
function Color() {
}
__name(Color, "Color");
var darker = 0.7;
var brighter = 1 / darker;
var reI = "\\s*([+-]?\\d+)\\s*", reN = "\\s*([+-]?(?:\\d*\\.)?\\d+(?:[eE][+-]?\\d+)?)\\s*", reP = "\\s*([+-]?(?:\\d*\\.)?\\d+(?:[eE][+-]?\\d+)?)%\\s*", reHex = /^#([0-9a-f]{3,8})$/, reRgbInteger = new RegExp(`^rgb\\(${reI},${reI},${reI}\\)$`), reRgbPercent = new RegExp(`^rgb\\(${reP},${reP},${reP}\\)$`), reRgbaInteger = new RegExp(`^rgba\\(${reI},${reI},${reI},${reN}\\)$`), reRgbaPercent = new RegExp(`^rgba\\(${reP},${reP},${reP},${reN}\\)$`), reHslPercent = new RegExp(`^hsl\\(${reN},${reP},${reP}\\)$`), reHslaPercent = new RegExp(`^hsla\\(${reN},${reP},${reP},${reN}\\)$`);
var named = {
  aliceblue: 15792383,
  antiquewhite: 16444375,
  aqua: 65535,
  aquamarine: 8388564,
  azure: 15794175,
  beige: 16119260,
  bisque: 16770244,
  black: 0,
  blanchedalmond: 16772045,
  blue: 255,
  blueviolet: 9055202,
  brown: 10824234,
  burlywood: 14596231,
  cadetblue: 6266528,
  chartreuse: 8388352,
  chocolate: 13789470,
  coral: 16744272,
  cornflowerblue: 6591981,
  cornsilk: 16775388,
  crimson: 14423100,
  cyan: 65535,
  darkblue: 139,
  darkcyan: 35723,
  darkgoldenrod: 12092939,
  darkgray: 11119017,
  darkgreen: 25600,
  darkgrey: 11119017,
  darkkhaki: 12433259,
  darkmagenta: 9109643,
  darkolivegreen: 5597999,
  darkorange: 16747520,
  darkorchid: 10040012,
  darkred: 9109504,
  darksalmon: 15308410,
  darkseagreen: 9419919,
  darkslateblue: 4734347,
  darkslategray: 3100495,
  darkslategrey: 3100495,
  darkturquoise: 52945,
  darkviolet: 9699539,
  deeppink: 16716947,
  deepskyblue: 49151,
  dimgray: 6908265,
  dimgrey: 6908265,
  dodgerblue: 2003199,
  firebrick: 11674146,
  floralwhite: 16775920,
  forestgreen: 2263842,
  fuchsia: 16711935,
  gainsboro: 14474460,
  ghostwhite: 16316671,
  gold: 16766720,
  goldenrod: 14329120,
  gray: 8421504,
  green: 32768,
  greenyellow: 11403055,
  grey: 8421504,
  honeydew: 15794160,
  hotpink: 16738740,
  indianred: 13458524,
  indigo: 4915330,
  ivory: 16777200,
  khaki: 15787660,
  lavender: 15132410,
  lavenderblush: 16773365,
  lawngreen: 8190976,
  lemonchiffon: 16775885,
  lightblue: 11393254,
  lightcoral: 15761536,
  lightcyan: 14745599,
  lightgoldenrodyellow: 16448210,
  lightgray: 13882323,
  lightgreen: 9498256,
  lightgrey: 13882323,
  lightpink: 16758465,
  lightsalmon: 16752762,
  lightseagreen: 2142890,
  lightskyblue: 8900346,
  lightslategray: 7833753,
  lightslategrey: 7833753,
  lightsteelblue: 11584734,
  lightyellow: 16777184,
  lime: 65280,
  limegreen: 3329330,
  linen: 16445670,
  magenta: 16711935,
  maroon: 8388608,
  mediumaquamarine: 6737322,
  mediumblue: 205,
  mediumorchid: 12211667,
  mediumpurple: 9662683,
  mediumseagreen: 3978097,
  mediumslateblue: 8087790,
  mediumspringgreen: 64154,
  mediumturquoise: 4772300,
  mediumvioletred: 13047173,
  midnightblue: 1644912,
  mintcream: 16121850,
  mistyrose: 16770273,
  moccasin: 16770229,
  navajowhite: 16768685,
  navy: 128,
  oldlace: 16643558,
  olive: 8421376,
  olivedrab: 7048739,
  orange: 16753920,
  orangered: 16729344,
  orchid: 14315734,
  palegoldenrod: 15657130,
  palegreen: 10025880,
  paleturquoise: 11529966,
  palevioletred: 14381203,
  papayawhip: 16773077,
  peachpuff: 16767673,
  peru: 13468991,
  pink: 16761035,
  plum: 14524637,
  powderblue: 11591910,
  purple: 8388736,
  rebeccapurple: 6697881,
  red: 16711680,
  rosybrown: 12357519,
  royalblue: 4286945,
  saddlebrown: 9127187,
  salmon: 16416882,
  sandybrown: 16032864,
  seagreen: 3050327,
  seashell: 16774638,
  sienna: 10506797,
  silver: 12632256,
  skyblue: 8900331,
  slateblue: 6970061,
  slategray: 7372944,
  slategrey: 7372944,
  snow: 16775930,
  springgreen: 65407,
  steelblue: 4620980,
  tan: 13808780,
  teal: 32896,
  thistle: 14204888,
  tomato: 16737095,
  turquoise: 4251856,
  violet: 15631086,
  wheat: 16113331,
  white: 16777215,
  whitesmoke: 16119285,
  yellow: 16776960,
  yellowgreen: 10145074
};
define(Color, color, {
  copy(channels) {
    return Object.assign(new this.constructor(), this, channels);
  },
  displayable() {
    return this.rgb().displayable();
  },
  hex: color_formatHex,
  formatHex: color_formatHex,
  formatHex8: color_formatHex8,
  formatHsl: color_formatHsl,
  formatRgb: color_formatRgb,
  toString: color_formatRgb
});
function color_formatHex() {
  return this.rgb().formatHex();
}
__name(color_formatHex, "color_formatHex");
function color_formatHex8() {
  return this.rgb().formatHex8();
}
__name(color_formatHex8, "color_formatHex8");
function color_formatHsl() {
  return hslConvert(this).formatHsl();
}
__name(color_formatHsl, "color_formatHsl");
function color_formatRgb() {
  return this.rgb().formatRgb();
}
__name(color_formatRgb, "color_formatRgb");
function color(format2) {
  var m, l;
  format2 = (format2 + "").trim().toLowerCase();
  return (m = reHex.exec(format2)) ? (l = m[1].length, m = parseInt(m[1], 16), l === 6 ? rgbn(m) : l === 3 ? new Rgb(m >> 8 & 15 | m >> 4 & 240, m >> 4 & 15 | m & 240, (m & 15) << 4 | m & 15, 1) : l === 8 ? rgba(m >> 24 & 255, m >> 16 & 255, m >> 8 & 255, (m & 255) / 255) : l === 4 ? rgba(m >> 12 & 15 | m >> 8 & 240, m >> 8 & 15 | m >> 4 & 240, m >> 4 & 15 | m & 240, ((m & 15) << 4 | m & 15) / 255) : null) : (m = reRgbInteger.exec(format2)) ? new Rgb(m[1], m[2], m[3], 1) : (m = reRgbPercent.exec(format2)) ? new Rgb(m[1] * 255 / 100, m[2] * 255 / 100, m[3] * 255 / 100, 1) : (m = reRgbaInteger.exec(format2)) ? rgba(m[1], m[2], m[3], m[4]) : (m = reRgbaPercent.exec(format2)) ? rgba(m[1] * 255 / 100, m[2] * 255 / 100, m[3] * 255 / 100, m[4]) : (m = reHslPercent.exec(format2)) ? hsla(m[1], m[2] / 100, m[3] / 100, 1) : (m = reHslaPercent.exec(format2)) ? hsla(m[1], m[2] / 100, m[3] / 100, m[4]) : named.hasOwnProperty(format2) ? rgbn(named[format2]) : format2 === "transparent" ? new Rgb(NaN, NaN, NaN, 0) : null;
}
__name(color, "color");
function rgbn(n) {
  return new Rgb(n >> 16 & 255, n >> 8 & 255, n & 255, 1);
}
__name(rgbn, "rgbn");
function rgba(r, g, b, a) {
  if (a <= 0)
    r = g = b = NaN;
  return new Rgb(r, g, b, a);
}
__name(rgba, "rgba");
function rgbConvert(o) {
  if (!(o instanceof Color))
    o = color(o);
  if (!o)
    return new Rgb();
  o = o.rgb();
  return new Rgb(o.r, o.g, o.b, o.opacity);
}
__name(rgbConvert, "rgbConvert");
function rgb(r, g, b, opacity) {
  return arguments.length === 1 ? rgbConvert(r) : new Rgb(r, g, b, opacity == null ? 1 : opacity);
}
__name(rgb, "rgb");
function Rgb(r, g, b, opacity) {
  this.r = +r;
  this.g = +g;
  this.b = +b;
  this.opacity = +opacity;
}
__name(Rgb, "Rgb");
define(Rgb, rgb, extend(Color, {
  brighter(k) {
    k = k == null ? brighter : Math.pow(brighter, k);
    return new Rgb(this.r * k, this.g * k, this.b * k, this.opacity);
  },
  darker(k) {
    k = k == null ? darker : Math.pow(darker, k);
    return new Rgb(this.r * k, this.g * k, this.b * k, this.opacity);
  },
  rgb() {
    return this;
  },
  clamp() {
    return new Rgb(clampi(this.r), clampi(this.g), clampi(this.b), clampa(this.opacity));
  },
  displayable() {
    return -0.5 <= this.r && this.r < 255.5 && (-0.5 <= this.g && this.g < 255.5) && (-0.5 <= this.b && this.b < 255.5) && (0 <= this.opacity && this.opacity <= 1);
  },
  hex: rgb_formatHex,
  formatHex: rgb_formatHex,
  formatHex8: rgb_formatHex8,
  formatRgb: rgb_formatRgb,
  toString: rgb_formatRgb
}));
function rgb_formatHex() {
  return `#${hex(this.r)}${hex(this.g)}${hex(this.b)}`;
}
__name(rgb_formatHex, "rgb_formatHex");
function rgb_formatHex8() {
  return `#${hex(this.r)}${hex(this.g)}${hex(this.b)}${hex((isNaN(this.opacity) ? 1 : this.opacity) * 255)}`;
}
__name(rgb_formatHex8, "rgb_formatHex8");
function rgb_formatRgb() {
  const a = clampa(this.opacity);
  return `${a === 1 ? "rgb(" : "rgba("}${clampi(this.r)}, ${clampi(this.g)}, ${clampi(this.b)}${a === 1 ? ")" : `, ${a})`}`;
}
__name(rgb_formatRgb, "rgb_formatRgb");
function clampa(opacity) {
  return isNaN(opacity) ? 1 : Math.max(0, Math.min(1, opacity));
}
__name(clampa, "clampa");
function clampi(value) {
  return Math.max(0, Math.min(255, Math.round(value) || 0));
}
__name(clampi, "clampi");
function hex(value) {
  value = clampi(value);
  return (value < 16 ? "0" : "") + value.toString(16);
}
__name(hex, "hex");
function hsla(h, s, l, a) {
  if (a <= 0)
    h = s = l = NaN;
  else if (l <= 0 || l >= 1)
    h = s = NaN;
  else if (s <= 0)
    h = NaN;
  return new Hsl(h, s, l, a);
}
__name(hsla, "hsla");
function hslConvert(o) {
  if (o instanceof Hsl)
    return new Hsl(o.h, o.s, o.l, o.opacity);
  if (!(o instanceof Color))
    o = color(o);
  if (!o)
    return new Hsl();
  if (o instanceof Hsl)
    return o;
  o = o.rgb();
  var r = o.r / 255, g = o.g / 255, b = o.b / 255, min = Math.min(r, g, b), max = Math.max(r, g, b), h = NaN, s = max - min, l = (max + min) / 2;
  if (s) {
    if (r === max)
      h = (g - b) / s + (g < b) * 6;
    else if (g === max)
      h = (b - r) / s + 2;
    else
      h = (r - g) / s + 4;
    s /= l < 0.5 ? max + min : 2 - max - min;
    h *= 60;
  } else {
    s = l > 0 && l < 1 ? 0 : h;
  }
  return new Hsl(h, s, l, o.opacity);
}
__name(hslConvert, "hslConvert");
function hsl(h, s, l, opacity) {
  return arguments.length === 1 ? hslConvert(h) : new Hsl(h, s, l, opacity == null ? 1 : opacity);
}
__name(hsl, "hsl");
function Hsl(h, s, l, opacity) {
  this.h = +h;
  this.s = +s;
  this.l = +l;
  this.opacity = +opacity;
}
__name(Hsl, "Hsl");
define(Hsl, hsl, extend(Color, {
  brighter(k) {
    k = k == null ? brighter : Math.pow(brighter, k);
    return new Hsl(this.h, this.s, this.l * k, this.opacity);
  },
  darker(k) {
    k = k == null ? darker : Math.pow(darker, k);
    return new Hsl(this.h, this.s, this.l * k, this.opacity);
  },
  rgb() {
    var h = this.h % 360 + (this.h < 0) * 360, s = isNaN(h) || isNaN(this.s) ? 0 : this.s, l = this.l, m2 = l + (l < 0.5 ? l : 1 - l) * s, m1 = 2 * l - m2;
    return new Rgb(
      hsl2rgb(h >= 240 ? h - 240 : h + 120, m1, m2),
      hsl2rgb(h, m1, m2),
      hsl2rgb(h < 120 ? h + 240 : h - 120, m1, m2),
      this.opacity
    );
  },
  clamp() {
    return new Hsl(clamph(this.h), clampt(this.s), clampt(this.l), clampa(this.opacity));
  },
  displayable() {
    return (0 <= this.s && this.s <= 1 || isNaN(this.s)) && (0 <= this.l && this.l <= 1) && (0 <= this.opacity && this.opacity <= 1);
  },
  formatHsl() {
    const a = clampa(this.opacity);
    return `${a === 1 ? "hsl(" : "hsla("}${clamph(this.h)}, ${clampt(this.s) * 100}%, ${clampt(this.l) * 100}%${a === 1 ? ")" : `, ${a})`}`;
  }
}));
function clamph(value) {
  value = (value || 0) % 360;
  return value < 0 ? value + 360 : value;
}
__name(clamph, "clamph");
function clampt(value) {
  return Math.max(0, Math.min(1, value || 0));
}
__name(clampt, "clampt");
function hsl2rgb(h, m1, m2) {
  return (h < 60 ? m1 + (m2 - m1) * h / 60 : h < 180 ? m2 : h < 240 ? m1 + (m2 - m1) * (240 - h) / 60 : m1) * 255;
}
__name(hsl2rgb, "hsl2rgb");
const constant$1 = /* @__PURE__ */ __name((x) => () => x, "constant$1");
function linear$1(a, d) {
  return function(t) {
    return a + t * d;
  };
}
__name(linear$1, "linear$1");
function exponential(a, b, y) {
  return a = Math.pow(a, y), b = Math.pow(b, y) - a, y = 1 / y, function(t) {
    return Math.pow(a + t * b, y);
  };
}
__name(exponential, "exponential");
function gamma(y) {
  return (y = +y) === 1 ? nogamma : function(a, b) {
    return b - a ? exponential(a, b, y) : constant$1(isNaN(a) ? b : a);
  };
}
__name(gamma, "gamma");
function nogamma(a, b) {
  var d = b - a;
  return d ? linear$1(a, d) : constant$1(isNaN(a) ? b : a);
}
__name(nogamma, "nogamma");
const interpolateRgb = (/* @__PURE__ */ __name(function rgbGamma(y) {
  var color2 = gamma(y);
  function rgb$1(start2, end) {
    var r = color2((start2 = rgb(start2)).r, (end = rgb(end)).r), g = color2(start2.g, end.g), b = color2(start2.b, end.b), opacity = nogamma(start2.opacity, end.opacity);
    return function(t) {
      start2.r = r(t);
      start2.g = g(t);
      start2.b = b(t);
      start2.opacity = opacity(t);
      return start2 + "";
    };
  }
  __name(rgb$1, "rgb$1");
  rgb$1.gamma = rgbGamma;
  return rgb$1;
}, "rgbGamma"))(1);
function numberArray(a, b) {
  if (!b)
    b = [];
  var n = a ? Math.min(b.length, a.length) : 0, c = b.slice(), i;
  return function(t) {
    for (i = 0; i < n; ++i)
      c[i] = a[i] * (1 - t) + b[i] * t;
    return c;
  };
}
__name(numberArray, "numberArray");
function isNumberArray(x) {
  return ArrayBuffer.isView(x) && !(x instanceof DataView);
}
__name(isNumberArray, "isNumberArray");
function genericArray(a, b) {
  var nb = b ? b.length : 0, na = a ? Math.min(nb, a.length) : 0, x = new Array(na), c = new Array(nb), i;
  for (i = 0; i < na; ++i)
    x[i] = interpolate$1(a[i], b[i]);
  for (; i < nb; ++i)
    c[i] = b[i];
  return function(t) {
    for (i = 0; i < na; ++i)
      c[i] = x[i](t);
    return c;
  };
}
__name(genericArray, "genericArray");
function date(a, b) {
  var d = new Date();
  return a = +a, b = +b, function(t) {
    return d.setTime(a * (1 - t) + b * t), d;
  };
}
__name(date, "date");
function interpolateNumber(a, b) {
  return a = +a, b = +b, function(t) {
    return a * (1 - t) + b * t;
  };
}
__name(interpolateNumber, "interpolateNumber");
function object(a, b) {
  var i = {}, c = {}, k;
  if (a === null || typeof a !== "object")
    a = {};
  if (b === null || typeof b !== "object")
    b = {};
  for (k in b) {
    if (k in a) {
      i[k] = interpolate$1(a[k], b[k]);
    } else {
      c[k] = b[k];
    }
  }
  return function(t) {
    for (k in i)
      c[k] = i[k](t);
    return c;
  };
}
__name(object, "object");
var reA = /[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g, reB = new RegExp(reA.source, "g");
function zero(b) {
  return function() {
    return b;
  };
}
__name(zero, "zero");
function one(b) {
  return function(t) {
    return b(t) + "";
  };
}
__name(one, "one");
function interpolateString(a, b) {
  var bi = reA.lastIndex = reB.lastIndex = 0, am, bm, bs, i = -1, s = [], q = [];
  a = a + "", b = b + "";
  while ((am = reA.exec(a)) && (bm = reB.exec(b))) {
    if ((bs = bm.index) > bi) {
      bs = b.slice(bi, bs);
      if (s[i])
        s[i] += bs;
      else
        s[++i] = bs;
    }
    if ((am = am[0]) === (bm = bm[0])) {
      if (s[i])
        s[i] += bm;
      else
        s[++i] = bm;
    } else {
      s[++i] = null;
      q.push({ i, x: interpolateNumber(am, bm) });
    }
    bi = reB.lastIndex;
  }
  if (bi < b.length) {
    bs = b.slice(bi);
    if (s[i])
      s[i] += bs;
    else
      s[++i] = bs;
  }
  return s.length < 2 ? q[0] ? one(q[0].x) : zero(b) : (b = q.length, function(t) {
    for (var i2 = 0, o; i2 < b; ++i2)
      s[(o = q[i2]).i] = o.x(t);
    return s.join("");
  });
}
__name(interpolateString, "interpolateString");
function interpolate$1(a, b) {
  var t = typeof b, c;
  return b == null || t === "boolean" ? constant$1(b) : (t === "number" ? interpolateNumber : t === "string" ? (c = color(b)) ? (b = c, interpolateRgb) : interpolateString : b instanceof color ? interpolateRgb : b instanceof Date ? date : isNumberArray(b) ? numberArray : Array.isArray(b) ? genericArray : typeof b.valueOf !== "function" && typeof b.toString !== "function" || isNaN(b) ? object : interpolateNumber)(a, b);
}
__name(interpolate$1, "interpolate$1");
function interpolateRound(a, b) {
  return a = +a, b = +b, function(t) {
    return Math.round(a * (1 - t) + b * t);
  };
}
__name(interpolateRound, "interpolateRound");
var degrees = 180 / Math.PI;
var identity$2 = {
  translateX: 0,
  translateY: 0,
  rotate: 0,
  skewX: 0,
  scaleX: 1,
  scaleY: 1
};
function decompose(a, b, c, d, e, f) {
  var scaleX, scaleY, skewX;
  if (scaleX = Math.sqrt(a * a + b * b))
    a /= scaleX, b /= scaleX;
  if (skewX = a * c + b * d)
    c -= a * skewX, d -= b * skewX;
  if (scaleY = Math.sqrt(c * c + d * d))
    c /= scaleY, d /= scaleY, skewX /= scaleY;
  if (a * d < b * c)
    a = -a, b = -b, skewX = -skewX, scaleX = -scaleX;
  return {
    translateX: e,
    translateY: f,
    rotate: Math.atan2(b, a) * degrees,
    skewX: Math.atan(skewX) * degrees,
    scaleX,
    scaleY
  };
}
__name(decompose, "decompose");
var svgNode;
function parseCss(value) {
  const m = new (typeof DOMMatrix === "function" ? DOMMatrix : WebKitCSSMatrix)(value + "");
  return m.isIdentity ? identity$2 : decompose(m.a, m.b, m.c, m.d, m.e, m.f);
}
__name(parseCss, "parseCss");
function parseSvg(value) {
  if (value == null)
    return identity$2;
  if (!svgNode)
    svgNode = document.createElementNS("http://www.w3.org/2000/svg", "g");
  svgNode.setAttribute("transform", value);
  if (!(value = svgNode.transform.baseVal.consolidate()))
    return identity$2;
  value = value.matrix;
  return decompose(value.a, value.b, value.c, value.d, value.e, value.f);
}
__name(parseSvg, "parseSvg");
function interpolateTransform(parse, pxComma, pxParen, degParen) {
  function pop(s) {
    return s.length ? s.pop() + " " : "";
  }
  __name(pop, "pop");
  function translate(xa, ya, xb, yb, s, q) {
    if (xa !== xb || ya !== yb) {
      var i = s.push("translate(", null, pxComma, null, pxParen);
      q.push({ i: i - 4, x: interpolateNumber(xa, xb) }, { i: i - 2, x: interpolateNumber(ya, yb) });
    } else if (xb || yb) {
      s.push("translate(" + xb + pxComma + yb + pxParen);
    }
  }
  __name(translate, "translate");
  function rotate(a, b, s, q) {
    if (a !== b) {
      if (a - b > 180)
        b += 360;
      else if (b - a > 180)
        a += 360;
      q.push({ i: s.push(pop(s) + "rotate(", null, degParen) - 2, x: interpolateNumber(a, b) });
    } else if (b) {
      s.push(pop(s) + "rotate(" + b + degParen);
    }
  }
  __name(rotate, "rotate");
  function skewX(a, b, s, q) {
    if (a !== b) {
      q.push({ i: s.push(pop(s) + "skewX(", null, degParen) - 2, x: interpolateNumber(a, b) });
    } else if (b) {
      s.push(pop(s) + "skewX(" + b + degParen);
    }
  }
  __name(skewX, "skewX");
  function scale(xa, ya, xb, yb, s, q) {
    if (xa !== xb || ya !== yb) {
      var i = s.push(pop(s) + "scale(", null, ",", null, ")");
      q.push({ i: i - 4, x: interpolateNumber(xa, xb) }, { i: i - 2, x: interpolateNumber(ya, yb) });
    } else if (xb !== 1 || yb !== 1) {
      s.push(pop(s) + "scale(" + xb + "," + yb + ")");
    }
  }
  __name(scale, "scale");
  return function(a, b) {
    var s = [], q = [];
    a = parse(a), b = parse(b);
    translate(a.translateX, a.translateY, b.translateX, b.translateY, s, q);
    rotate(a.rotate, b.rotate, s, q);
    skewX(a.skewX, b.skewX, s, q);
    scale(a.scaleX, a.scaleY, b.scaleX, b.scaleY, s, q);
    a = b = null;
    return function(t) {
      var i = -1, n = q.length, o;
      while (++i < n)
        s[(o = q[i]).i] = o.x(t);
      return s.join("");
    };
  };
}
__name(interpolateTransform, "interpolateTransform");
var interpolateTransformCss = interpolateTransform(parseCss, "px, ", "px)", "deg)");
var interpolateTransformSvg = interpolateTransform(parseSvg, ", ", ")", ")");
var frame = 0, timeout$1 = 0, interval = 0, pokeDelay = 1e3, taskHead, taskTail, clockLast = 0, clockNow = 0, clockSkew = 0, clock = typeof performance === "object" && performance.now ? performance : Date, setFrame = typeof window === "object" && window.requestAnimationFrame ? window.requestAnimationFrame.bind(window) : function(f) {
  setTimeout(f, 17);
};
function now() {
  return clockNow || (setFrame(clearNow), clockNow = clock.now() + clockSkew);
}
__name(now, "now");
function clearNow() {
  clockNow = 0;
}
__name(clearNow, "clearNow");
function Timer() {
  this._call = this._time = this._next = null;
}
__name(Timer, "Timer");
Timer.prototype = timer.prototype = {
  constructor: Timer,
  restart: function(callback, delay, time) {
    if (typeof callback !== "function")
      throw new TypeError("callback is not a function");
    time = (time == null ? now() : +time) + (delay == null ? 0 : +delay);
    if (!this._next && taskTail !== this) {
      if (taskTail)
        taskTail._next = this;
      else
        taskHead = this;
      taskTail = this;
    }
    this._call = callback;
    this._time = time;
    sleep();
  },
  stop: function() {
    if (this._call) {
      this._call = null;
      this._time = Infinity;
      sleep();
    }
  }
};
function timer(callback, delay, time) {
  var t = new Timer();
  t.restart(callback, delay, time);
  return t;
}
__name(timer, "timer");
function timerFlush() {
  now();
  ++frame;
  var t = taskHead, e;
  while (t) {
    if ((e = clockNow - t._time) >= 0)
      t._call.call(void 0, e);
    t = t._next;
  }
  --frame;
}
__name(timerFlush, "timerFlush");
function wake() {
  clockNow = (clockLast = clock.now()) + clockSkew;
  frame = timeout$1 = 0;
  try {
    timerFlush();
  } finally {
    frame = 0;
    nap();
    clockNow = 0;
  }
}
__name(wake, "wake");
function poke() {
  var now2 = clock.now(), delay = now2 - clockLast;
  if (delay > pokeDelay)
    clockSkew -= delay, clockLast = now2;
}
__name(poke, "poke");
function nap() {
  var t0, t1 = taskHead, t2, time = Infinity;
  while (t1) {
    if (t1._call) {
      if (time > t1._time)
        time = t1._time;
      t0 = t1, t1 = t1._next;
    } else {
      t2 = t1._next, t1._next = null;
      t1 = t0 ? t0._next = t2 : taskHead = t2;
    }
  }
  taskTail = t0;
  sleep(time);
}
__name(nap, "nap");
function sleep(time) {
  if (frame)
    return;
  if (timeout$1)
    timeout$1 = clearTimeout(timeout$1);
  var delay = time - clockNow;
  if (delay > 24) {
    if (time < Infinity)
      timeout$1 = setTimeout(wake, time - clock.now() - clockSkew);
    if (interval)
      interval = clearInterval(interval);
  } else {
    if (!interval)
      clockLast = clock.now(), interval = setInterval(poke, pokeDelay);
    frame = 1, setFrame(wake);
  }
}
__name(sleep, "sleep");
function timeout(callback, delay, time) {
  var t = new Timer();
  delay = delay == null ? 0 : +delay;
  t.restart((elapsed) => {
    t.stop();
    callback(elapsed + delay);
  }, delay, time);
  return t;
}
__name(timeout, "timeout");
var emptyOn = dispatch("start", "end", "cancel", "interrupt");
var emptyTween = [];
var CREATED = 0;
var SCHEDULED = 1;
var STARTING = 2;
var STARTED = 3;
var RUNNING = 4;
var ENDING = 5;
var ENDED = 6;
function schedule(node, name, id2, index, group, timing) {
  var schedules = node.__transition;
  if (!schedules)
    node.__transition = {};
  else if (id2 in schedules)
    return;
  create(node, id2, {
    name,
    index,
    group,
    on: emptyOn,
    tween: emptyTween,
    time: timing.time,
    delay: timing.delay,
    duration: timing.duration,
    ease: timing.ease,
    timer: null,
    state: CREATED
  });
}
__name(schedule, "schedule");
function init(node, id2) {
  var schedule2 = get(node, id2);
  if (schedule2.state > CREATED)
    throw new Error("too late; already scheduled");
  return schedule2;
}
__name(init, "init");
function set(node, id2) {
  var schedule2 = get(node, id2);
  if (schedule2.state > STARTED)
    throw new Error("too late; already running");
  return schedule2;
}
__name(set, "set");
function get(node, id2) {
  var schedule2 = node.__transition;
  if (!schedule2 || !(schedule2 = schedule2[id2]))
    throw new Error("transition not found");
  return schedule2;
}
__name(get, "get");
function create(node, id2, self) {
  var schedules = node.__transition, tween;
  schedules[id2] = self;
  self.timer = timer(schedule2, 0, self.time);
  function schedule2(elapsed) {
    self.state = SCHEDULED;
    self.timer.restart(start2, self.delay, self.time);
    if (self.delay <= elapsed)
      start2(elapsed - self.delay);
  }
  __name(schedule2, "schedule");
  function start2(elapsed) {
    var i, j, n, o;
    if (self.state !== SCHEDULED)
      return stop();
    for (i in schedules) {
      o = schedules[i];
      if (o.name !== self.name)
        continue;
      if (o.state === STARTED)
        return timeout(start2);
      if (o.state === RUNNING) {
        o.state = ENDED;
        o.timer.stop();
        o.on.call("interrupt", node, node.__data__, o.index, o.group);
        delete schedules[i];
      } else if (+i < id2) {
        o.state = ENDED;
        o.timer.stop();
        o.on.call("cancel", node, node.__data__, o.index, o.group);
        delete schedules[i];
      }
    }
    timeout(function() {
      if (self.state === STARTED) {
        self.state = RUNNING;
        self.timer.restart(tick, self.delay, self.time);
        tick(elapsed);
      }
    });
    self.state = STARTING;
    self.on.call("start", node, node.__data__, self.index, self.group);
    if (self.state !== STARTING)
      return;
    self.state = STARTED;
    tween = new Array(n = self.tween.length);
    for (i = 0, j = -1; i < n; ++i) {
      if (o = self.tween[i].value.call(node, node.__data__, self.index, self.group)) {
        tween[++j] = o;
      }
    }
    tween.length = j + 1;
  }
  __name(start2, "start");
  function tick(elapsed) {
    var t = elapsed < self.duration ? self.ease.call(null, elapsed / self.duration) : (self.timer.restart(stop), self.state = ENDING, 1), i = -1, n = tween.length;
    while (++i < n) {
      tween[i].call(node, t);
    }
    if (self.state === ENDING) {
      self.on.call("end", node, node.__data__, self.index, self.group);
      stop();
    }
  }
  __name(tick, "tick");
  function stop() {
    self.state = ENDED;
    self.timer.stop();
    delete schedules[id2];
    for (var i in schedules)
      return;
    delete node.__transition;
  }
  __name(stop, "stop");
}
__name(create, "create");
function interrupt(node, name) {
  var schedules = node.__transition, schedule2, active, empty2 = true, i;
  if (!schedules)
    return;
  name = name == null ? null : name + "";
  for (i in schedules) {
    if ((schedule2 = schedules[i]).name !== name) {
      empty2 = false;
      continue;
    }
    active = schedule2.state > STARTING && schedule2.state < ENDING;
    schedule2.state = ENDED;
    schedule2.timer.stop();
    schedule2.on.call(active ? "interrupt" : "cancel", node, node.__data__, schedule2.index, schedule2.group);
    delete schedules[i];
  }
  if (empty2)
    delete node.__transition;
}
__name(interrupt, "interrupt");
function selection_interrupt(name) {
  return this.each(function() {
    interrupt(this, name);
  });
}
__name(selection_interrupt, "selection_interrupt");
function tweenRemove(id2, name) {
  var tween0, tween1;
  return function() {
    var schedule2 = set(this, id2), tween = schedule2.tween;
    if (tween !== tween0) {
      tween1 = tween0 = tween;
      for (var i = 0, n = tween1.length; i < n; ++i) {
        if (tween1[i].name === name) {
          tween1 = tween1.slice();
          tween1.splice(i, 1);
          break;
        }
      }
    }
    schedule2.tween = tween1;
  };
}
__name(tweenRemove, "tweenRemove");
function tweenFunction(id2, name, value) {
  var tween0, tween1;
  if (typeof value !== "function")
    throw new Error();
  return function() {
    var schedule2 = set(this, id2), tween = schedule2.tween;
    if (tween !== tween0) {
      tween1 = (tween0 = tween).slice();
      for (var t = { name, value }, i = 0, n = tween1.length; i < n; ++i) {
        if (tween1[i].name === name) {
          tween1[i] = t;
          break;
        }
      }
      if (i === n)
        tween1.push(t);
    }
    schedule2.tween = tween1;
  };
}
__name(tweenFunction, "tweenFunction");
function transition_tween(name, value) {
  var id2 = this._id;
  name += "";
  if (arguments.length < 2) {
    var tween = get(this.node(), id2).tween;
    for (var i = 0, n = tween.length, t; i < n; ++i) {
      if ((t = tween[i]).name === name) {
        return t.value;
      }
    }
    return null;
  }
  return this.each((value == null ? tweenRemove : tweenFunction)(id2, name, value));
}
__name(transition_tween, "transition_tween");
function tweenValue(transition, name, value) {
  var id2 = transition._id;
  transition.each(function() {
    var schedule2 = set(this, id2);
    (schedule2.value || (schedule2.value = {}))[name] = value.apply(this, arguments);
  });
  return function(node) {
    return get(node, id2).value[name];
  };
}
__name(tweenValue, "tweenValue");
function interpolate(a, b) {
  var c;
  return (typeof b === "number" ? interpolateNumber : b instanceof color ? interpolateRgb : (c = color(b)) ? (b = c, interpolateRgb) : interpolateString)(a, b);
}
__name(interpolate, "interpolate");
function attrRemove(name) {
  return function() {
    this.removeAttribute(name);
  };
}
__name(attrRemove, "attrRemove");
function attrRemoveNS(fullname) {
  return function() {
    this.removeAttributeNS(fullname.space, fullname.local);
  };
}
__name(attrRemoveNS, "attrRemoveNS");
function attrConstant(name, interpolate2, value1) {
  var string00, string1 = value1 + "", interpolate0;
  return function() {
    var string0 = this.getAttribute(name);
    return string0 === string1 ? null : string0 === string00 ? interpolate0 : interpolate0 = interpolate2(string00 = string0, value1);
  };
}
__name(attrConstant, "attrConstant");
function attrConstantNS(fullname, interpolate2, value1) {
  var string00, string1 = value1 + "", interpolate0;
  return function() {
    var string0 = this.getAttributeNS(fullname.space, fullname.local);
    return string0 === string1 ? null : string0 === string00 ? interpolate0 : interpolate0 = interpolate2(string00 = string0, value1);
  };
}
__name(attrConstantNS, "attrConstantNS");
function attrFunction(name, interpolate2, value) {
  var string00, string10, interpolate0;
  return function() {
    var string0, value1 = value(this), string1;
    if (value1 == null)
      return void this.removeAttribute(name);
    string0 = this.getAttribute(name);
    string1 = value1 + "";
    return string0 === string1 ? null : string0 === string00 && string1 === string10 ? interpolate0 : (string10 = string1, interpolate0 = interpolate2(string00 = string0, value1));
  };
}
__name(attrFunction, "attrFunction");
function attrFunctionNS(fullname, interpolate2, value) {
  var string00, string10, interpolate0;
  return function() {
    var string0, value1 = value(this), string1;
    if (value1 == null)
      return void this.removeAttributeNS(fullname.space, fullname.local);
    string0 = this.getAttributeNS(fullname.space, fullname.local);
    string1 = value1 + "";
    return string0 === string1 ? null : string0 === string00 && string1 === string10 ? interpolate0 : (string10 = string1, interpolate0 = interpolate2(string00 = string0, value1));
  };
}
__name(attrFunctionNS, "attrFunctionNS");
function transition_attr(name, value) {
  var fullname = namespace(name), i = fullname === "transform" ? interpolateTransformSvg : interpolate;
  return this.attrTween(name, typeof value === "function" ? (fullname.local ? attrFunctionNS : attrFunction)(fullname, i, tweenValue(this, "attr." + name, value)) : value == null ? (fullname.local ? attrRemoveNS : attrRemove)(fullname) : (fullname.local ? attrConstantNS : attrConstant)(fullname, i, value));
}
__name(transition_attr, "transition_attr");
function attrInterpolate(name, i) {
  return function(t) {
    this.setAttribute(name, i.call(this, t));
  };
}
__name(attrInterpolate, "attrInterpolate");
function attrInterpolateNS(fullname, i) {
  return function(t) {
    this.setAttributeNS(fullname.space, fullname.local, i.call(this, t));
  };
}
__name(attrInterpolateNS, "attrInterpolateNS");
function attrTweenNS(fullname, value) {
  var t0, i0;
  function tween() {
    var i = value.apply(this, arguments);
    if (i !== i0)
      t0 = (i0 = i) && attrInterpolateNS(fullname, i);
    return t0;
  }
  __name(tween, "tween");
  tween._value = value;
  return tween;
}
__name(attrTweenNS, "attrTweenNS");
function attrTween(name, value) {
  var t0, i0;
  function tween() {
    var i = value.apply(this, arguments);
    if (i !== i0)
      t0 = (i0 = i) && attrInterpolate(name, i);
    return t0;
  }
  __name(tween, "tween");
  tween._value = value;
  return tween;
}
__name(attrTween, "attrTween");
function transition_attrTween(name, value) {
  var key = "attr." + name;
  if (arguments.length < 2)
    return (key = this.tween(key)) && key._value;
  if (value == null)
    return this.tween(key, null);
  if (typeof value !== "function")
    throw new Error();
  var fullname = namespace(name);
  return this.tween(key, (fullname.local ? attrTweenNS : attrTween)(fullname, value));
}
__name(transition_attrTween, "transition_attrTween");
function delayFunction(id2, value) {
  return function() {
    init(this, id2).delay = +value.apply(this, arguments);
  };
}
__name(delayFunction, "delayFunction");
function delayConstant(id2, value) {
  return value = +value, function() {
    init(this, id2).delay = value;
  };
}
__name(delayConstant, "delayConstant");
function transition_delay(value) {
  var id2 = this._id;
  return arguments.length ? this.each((typeof value === "function" ? delayFunction : delayConstant)(id2, value)) : get(this.node(), id2).delay;
}
__name(transition_delay, "transition_delay");
function durationFunction(id2, value) {
  return function() {
    set(this, id2).duration = +value.apply(this, arguments);
  };
}
__name(durationFunction, "durationFunction");
function durationConstant(id2, value) {
  return value = +value, function() {
    set(this, id2).duration = value;
  };
}
__name(durationConstant, "durationConstant");
function transition_duration(value) {
  var id2 = this._id;
  return arguments.length ? this.each((typeof value === "function" ? durationFunction : durationConstant)(id2, value)) : get(this.node(), id2).duration;
}
__name(transition_duration, "transition_duration");
function easeConstant(id2, value) {
  if (typeof value !== "function")
    throw new Error();
  return function() {
    set(this, id2).ease = value;
  };
}
__name(easeConstant, "easeConstant");
function transition_ease(value) {
  var id2 = this._id;
  return arguments.length ? this.each(easeConstant(id2, value)) : get(this.node(), id2).ease;
}
__name(transition_ease, "transition_ease");
function easeVarying(id2, value) {
  return function() {
    var v = value.apply(this, arguments);
    if (typeof v !== "function")
      throw new Error();
    set(this, id2).ease = v;
  };
}
__name(easeVarying, "easeVarying");
function transition_easeVarying(value) {
  if (typeof value !== "function")
    throw new Error();
  return this.each(easeVarying(this._id, value));
}
__name(transition_easeVarying, "transition_easeVarying");
function transition_filter(match) {
  if (typeof match !== "function")
    match = matcher(match);
  for (var groups = this._groups, m = groups.length, subgroups = new Array(m), j = 0; j < m; ++j) {
    for (var group = groups[j], n = group.length, subgroup = subgroups[j] = [], node, i = 0; i < n; ++i) {
      if ((node = group[i]) && match.call(node, node.__data__, i, group)) {
        subgroup.push(node);
      }
    }
  }
  return new Transition(subgroups, this._parents, this._name, this._id);
}
__name(transition_filter, "transition_filter");
function transition_merge(transition) {
  if (transition._id !== this._id)
    throw new Error();
  for (var groups0 = this._groups, groups1 = transition._groups, m0 = groups0.length, m1 = groups1.length, m = Math.min(m0, m1), merges = new Array(m0), j = 0; j < m; ++j) {
    for (var group0 = groups0[j], group1 = groups1[j], n = group0.length, merge = merges[j] = new Array(n), node, i = 0; i < n; ++i) {
      if (node = group0[i] || group1[i]) {
        merge[i] = node;
      }
    }
  }
  for (; j < m0; ++j) {
    merges[j] = groups0[j];
  }
  return new Transition(merges, this._parents, this._name, this._id);
}
__name(transition_merge, "transition_merge");
function start(name) {
  return (name + "").trim().split(/^|\s+/).every(function(t) {
    var i = t.indexOf(".");
    if (i >= 0)
      t = t.slice(0, i);
    return !t || t === "start";
  });
}
__name(start, "start");
function onFunction(id2, name, listener) {
  var on0, on1, sit = start(name) ? init : set;
  return function() {
    var schedule2 = sit(this, id2), on = schedule2.on;
    if (on !== on0)
      (on1 = (on0 = on).copy()).on(name, listener);
    schedule2.on = on1;
  };
}
__name(onFunction, "onFunction");
function transition_on(name, listener) {
  var id2 = this._id;
  return arguments.length < 2 ? get(this.node(), id2).on.on(name) : this.each(onFunction(id2, name, listener));
}
__name(transition_on, "transition_on");
function removeFunction(id2) {
  return function() {
    var parent = this.parentNode;
    for (var i in this.__transition)
      if (+i !== id2)
        return;
    if (parent)
      parent.removeChild(this);
  };
}
__name(removeFunction, "removeFunction");
function transition_remove() {
  return this.on("end.remove", removeFunction(this._id));
}
__name(transition_remove, "transition_remove");
function transition_select(select2) {
  var name = this._name, id2 = this._id;
  if (typeof select2 !== "function")
    select2 = selector(select2);
  for (var groups = this._groups, m = groups.length, subgroups = new Array(m), j = 0; j < m; ++j) {
    for (var group = groups[j], n = group.length, subgroup = subgroups[j] = new Array(n), node, subnode, i = 0; i < n; ++i) {
      if ((node = group[i]) && (subnode = select2.call(node, node.__data__, i, group))) {
        if ("__data__" in node)
          subnode.__data__ = node.__data__;
        subgroup[i] = subnode;
        schedule(subgroup[i], name, id2, i, subgroup, get(node, id2));
      }
    }
  }
  return new Transition(subgroups, this._parents, name, id2);
}
__name(transition_select, "transition_select");
function transition_selectAll(select2) {
  var name = this._name, id2 = this._id;
  if (typeof select2 !== "function")
    select2 = selectorAll(select2);
  for (var groups = this._groups, m = groups.length, subgroups = [], parents = [], j = 0; j < m; ++j) {
    for (var group = groups[j], n = group.length, node, i = 0; i < n; ++i) {
      if (node = group[i]) {
        for (var children2 = select2.call(node, node.__data__, i, group), child, inherit2 = get(node, id2), k = 0, l = children2.length; k < l; ++k) {
          if (child = children2[k]) {
            schedule(child, name, id2, k, children2, inherit2);
          }
        }
        subgroups.push(children2);
        parents.push(node);
      }
    }
  }
  return new Transition(subgroups, parents, name, id2);
}
__name(transition_selectAll, "transition_selectAll");
var Selection = selection.prototype.constructor;
function transition_selection() {
  return new Selection(this._groups, this._parents);
}
__name(transition_selection, "transition_selection");
function styleNull(name, interpolate2) {
  var string00, string10, interpolate0;
  return function() {
    var string0 = styleValue(this, name), string1 = (this.style.removeProperty(name), styleValue(this, name));
    return string0 === string1 ? null : string0 === string00 && string1 === string10 ? interpolate0 : interpolate0 = interpolate2(string00 = string0, string10 = string1);
  };
}
__name(styleNull, "styleNull");
function styleRemove(name) {
  return function() {
    this.style.removeProperty(name);
  };
}
__name(styleRemove, "styleRemove");
function styleConstant(name, interpolate2, value1) {
  var string00, string1 = value1 + "", interpolate0;
  return function() {
    var string0 = styleValue(this, name);
    return string0 === string1 ? null : string0 === string00 ? interpolate0 : interpolate0 = interpolate2(string00 = string0, value1);
  };
}
__name(styleConstant, "styleConstant");
function styleFunction(name, interpolate2, value) {
  var string00, string10, interpolate0;
  return function() {
    var string0 = styleValue(this, name), value1 = value(this), string1 = value1 + "";
    if (value1 == null)
      string1 = value1 = (this.style.removeProperty(name), styleValue(this, name));
    return string0 === string1 ? null : string0 === string00 && string1 === string10 ? interpolate0 : (string10 = string1, interpolate0 = interpolate2(string00 = string0, value1));
  };
}
__name(styleFunction, "styleFunction");
function styleMaybeRemove(id2, name) {
  var on0, on1, listener0, key = "style." + name, event = "end." + key, remove2;
  return function() {
    var schedule2 = set(this, id2), on = schedule2.on, listener = schedule2.value[key] == null ? remove2 || (remove2 = styleRemove(name)) : void 0;
    if (on !== on0 || listener0 !== listener)
      (on1 = (on0 = on).copy()).on(event, listener0 = listener);
    schedule2.on = on1;
  };
}
__name(styleMaybeRemove, "styleMaybeRemove");
function transition_style(name, value, priority) {
  var i = (name += "") === "transform" ? interpolateTransformCss : interpolate;
  return value == null ? this.styleTween(name, styleNull(name, i)).on("end.style." + name, styleRemove(name)) : typeof value === "function" ? this.styleTween(name, styleFunction(name, i, tweenValue(this, "style." + name, value))).each(styleMaybeRemove(this._id, name)) : this.styleTween(name, styleConstant(name, i, value), priority).on("end.style." + name, null);
}
__name(transition_style, "transition_style");
function styleInterpolate(name, i, priority) {
  return function(t) {
    this.style.setProperty(name, i.call(this, t), priority);
  };
}
__name(styleInterpolate, "styleInterpolate");
function styleTween(name, value, priority) {
  var t, i0;
  function tween() {
    var i = value.apply(this, arguments);
    if (i !== i0)
      t = (i0 = i) && styleInterpolate(name, i, priority);
    return t;
  }
  __name(tween, "tween");
  tween._value = value;
  return tween;
}
__name(styleTween, "styleTween");
function transition_styleTween(name, value, priority) {
  var key = "style." + (name += "");
  if (arguments.length < 2)
    return (key = this.tween(key)) && key._value;
  if (value == null)
    return this.tween(key, null);
  if (typeof value !== "function")
    throw new Error();
  return this.tween(key, styleTween(name, value, priority == null ? "" : priority));
}
__name(transition_styleTween, "transition_styleTween");
function textConstant(value) {
  return function() {
    this.textContent = value;
  };
}
__name(textConstant, "textConstant");
function textFunction(value) {
  return function() {
    var value1 = value(this);
    this.textContent = value1 == null ? "" : value1;
  };
}
__name(textFunction, "textFunction");
function transition_text(value) {
  return this.tween("text", typeof value === "function" ? textFunction(tweenValue(this, "text", value)) : textConstant(value == null ? "" : value + ""));
}
__name(transition_text, "transition_text");
function textInterpolate(i) {
  return function(t) {
    this.textContent = i.call(this, t);
  };
}
__name(textInterpolate, "textInterpolate");
function textTween(value) {
  var t0, i0;
  function tween() {
    var i = value.apply(this, arguments);
    if (i !== i0)
      t0 = (i0 = i) && textInterpolate(i);
    return t0;
  }
  __name(tween, "tween");
  tween._value = value;
  return tween;
}
__name(textTween, "textTween");
function transition_textTween(value) {
  var key = "text";
  if (arguments.length < 1)
    return (key = this.tween(key)) && key._value;
  if (value == null)
    return this.tween(key, null);
  if (typeof value !== "function")
    throw new Error();
  return this.tween(key, textTween(value));
}
__name(transition_textTween, "transition_textTween");
function transition_transition() {
  var name = this._name, id0 = this._id, id1 = newId();
  for (var groups = this._groups, m = groups.length, j = 0; j < m; ++j) {
    for (var group = groups[j], n = group.length, node, i = 0; i < n; ++i) {
      if (node = group[i]) {
        var inherit2 = get(node, id0);
        schedule(node, name, id1, i, group, {
          time: inherit2.time + inherit2.delay + inherit2.duration,
          delay: 0,
          duration: inherit2.duration,
          ease: inherit2.ease
        });
      }
    }
  }
  return new Transition(groups, this._parents, name, id1);
}
__name(transition_transition, "transition_transition");
function transition_end() {
  var on0, on1, that = this, id2 = that._id, size = that.size();
  return new Promise(function(resolve, reject) {
    var cancel = { value: reject }, end = { value: function() {
      if (--size === 0)
        resolve();
    } };
    that.each(function() {
      var schedule2 = set(this, id2), on = schedule2.on;
      if (on !== on0) {
        on1 = (on0 = on).copy();
        on1._.cancel.push(cancel);
        on1._.interrupt.push(cancel);
        on1._.end.push(end);
      }
      schedule2.on = on1;
    });
    if (size === 0)
      resolve();
  });
}
__name(transition_end, "transition_end");
var id = 0;
function Transition(groups, parents, name, id2) {
  this._groups = groups;
  this._parents = parents;
  this._name = name;
  this._id = id2;
}
__name(Transition, "Transition");
function newId() {
  return ++id;
}
__name(newId, "newId");
var selection_prototype = selection.prototype;
Transition.prototype = {
  constructor: Transition,
  select: transition_select,
  selectAll: transition_selectAll,
  selectChild: selection_prototype.selectChild,
  selectChildren: selection_prototype.selectChildren,
  filter: transition_filter,
  merge: transition_merge,
  selection: transition_selection,
  transition: transition_transition,
  call: selection_prototype.call,
  nodes: selection_prototype.nodes,
  node: selection_prototype.node,
  size: selection_prototype.size,
  empty: selection_prototype.empty,
  each: selection_prototype.each,
  on: transition_on,
  attr: transition_attr,
  attrTween: transition_attrTween,
  style: transition_style,
  styleTween: transition_styleTween,
  text: transition_text,
  textTween: transition_textTween,
  remove: transition_remove,
  tween: transition_tween,
  delay: transition_delay,
  duration: transition_duration,
  ease: transition_ease,
  easeVarying: transition_easeVarying,
  end: transition_end,
  [Symbol.iterator]: selection_prototype[Symbol.iterator]
};
function cubicInOut(t) {
  return ((t *= 2) <= 1 ? t * t * t : (t -= 2) * t * t + 2) / 2;
}
__name(cubicInOut, "cubicInOut");
var defaultTiming = {
  time: null,
  delay: 0,
  duration: 250,
  ease: cubicInOut
};
function inherit(node, id2) {
  var timing;
  while (!(timing = node.__transition) || !(timing = timing[id2])) {
    if (!(node = node.parentNode)) {
      throw new Error(`transition ${id2} not found`);
    }
  }
  return timing;
}
__name(inherit, "inherit");
function selection_transition(name) {
  var id2, timing;
  if (name instanceof Transition) {
    id2 = name._id, name = name._name;
  } else {
    id2 = newId(), (timing = defaultTiming).time = now(), name = name == null ? null : name + "";
  }
  for (var groups = this._groups, m = groups.length, j = 0; j < m; ++j) {
    for (var group = groups[j], n = group.length, node, i = 0; i < n; ++i) {
      if (node = group[i]) {
        schedule(node, name, id2, i, group, timing || inherit(node, id2));
      }
    }
  }
  return new Transition(groups, this._parents, name, id2);
}
__name(selection_transition, "selection_transition");
selection.prototype.interrupt = selection_interrupt;
selection.prototype.transition = selection_transition;
function formatDecimal(x) {
  return Math.abs(x = Math.round(x)) >= 1e21 ? x.toLocaleString("en").replace(/,/g, "") : x.toString(10);
}
__name(formatDecimal, "formatDecimal");
function formatDecimalParts(x, p) {
  if ((i = (x = p ? x.toExponential(p - 1) : x.toExponential()).indexOf("e")) < 0)
    return null;
  var i, coefficient = x.slice(0, i);
  return [
    coefficient.length > 1 ? coefficient[0] + coefficient.slice(2) : coefficient,
    +x.slice(i + 1)
  ];
}
__name(formatDecimalParts, "formatDecimalParts");
function exponent(x) {
  return x = formatDecimalParts(Math.abs(x)), x ? x[1] : NaN;
}
__name(exponent, "exponent");
function formatGroup(grouping, thousands) {
  return function(value, width) {
    var i = value.length, t = [], j = 0, g = grouping[0], length = 0;
    while (i > 0 && g > 0) {
      if (length + g + 1 > width)
        g = Math.max(1, width - length);
      t.push(value.substring(i -= g, i + g));
      if ((length += g + 1) > width)
        break;
      g = grouping[j = (j + 1) % grouping.length];
    }
    return t.reverse().join(thousands);
  };
}
__name(formatGroup, "formatGroup");
function formatNumerals(numerals) {
  return function(value) {
    return value.replace(/[0-9]/g, function(i) {
      return numerals[+i];
    });
  };
}
__name(formatNumerals, "formatNumerals");
var re = /^(?:(.)?([<>=^]))?([+\-( ])?([$#])?(0)?(\d+)?(,)?(\.\d+)?(~)?([a-z%])?$/i;
function formatSpecifier(specifier) {
  if (!(match = re.exec(specifier)))
    throw new Error("invalid format: " + specifier);
  var match;
  return new FormatSpecifier({
    fill: match[1],
    align: match[2],
    sign: match[3],
    symbol: match[4],
    zero: match[5],
    width: match[6],
    comma: match[7],
    precision: match[8] && match[8].slice(1),
    trim: match[9],
    type: match[10]
  });
}
__name(formatSpecifier, "formatSpecifier");
formatSpecifier.prototype = FormatSpecifier.prototype;
function FormatSpecifier(specifier) {
  this.fill = specifier.fill === void 0 ? " " : specifier.fill + "";
  this.align = specifier.align === void 0 ? ">" : specifier.align + "";
  this.sign = specifier.sign === void 0 ? "-" : specifier.sign + "";
  this.symbol = specifier.symbol === void 0 ? "" : specifier.symbol + "";
  this.zero = !!specifier.zero;
  this.width = specifier.width === void 0 ? void 0 : +specifier.width;
  this.comma = !!specifier.comma;
  this.precision = specifier.precision === void 0 ? void 0 : +specifier.precision;
  this.trim = !!specifier.trim;
  this.type = specifier.type === void 0 ? "" : specifier.type + "";
}
__name(FormatSpecifier, "FormatSpecifier");
FormatSpecifier.prototype.toString = function() {
  return this.fill + this.align + this.sign + this.symbol + (this.zero ? "0" : "") + (this.width === void 0 ? "" : Math.max(1, this.width | 0)) + (this.comma ? "," : "") + (this.precision === void 0 ? "" : "." + Math.max(0, this.precision | 0)) + (this.trim ? "~" : "") + this.type;
};
function formatTrim(s) {
  out:
    for (var n = s.length, i = 1, i0 = -1, i1; i < n; ++i) {
      switch (s[i]) {
        case ".":
          i0 = i1 = i;
          break;
        case "0":
          if (i0 === 0)
            i0 = i;
          i1 = i;
          break;
        default:
          if (!+s[i])
            break out;
          if (i0 > 0)
            i0 = 0;
          break;
      }
    }
  return i0 > 0 ? s.slice(0, i0) + s.slice(i1 + 1) : s;
}
__name(formatTrim, "formatTrim");
var prefixExponent;
function formatPrefixAuto(x, p) {
  var d = formatDecimalParts(x, p);
  if (!d)
    return x + "";
  var coefficient = d[0], exponent2 = d[1], i = exponent2 - (prefixExponent = Math.max(-8, Math.min(8, Math.floor(exponent2 / 3))) * 3) + 1, n = coefficient.length;
  return i === n ? coefficient : i > n ? coefficient + new Array(i - n + 1).join("0") : i > 0 ? coefficient.slice(0, i) + "." + coefficient.slice(i) : "0." + new Array(1 - i).join("0") + formatDecimalParts(x, Math.max(0, p + i - 1))[0];
}
__name(formatPrefixAuto, "formatPrefixAuto");
function formatRounded(x, p) {
  var d = formatDecimalParts(x, p);
  if (!d)
    return x + "";
  var coefficient = d[0], exponent2 = d[1];
  return exponent2 < 0 ? "0." + new Array(-exponent2).join("0") + coefficient : coefficient.length > exponent2 + 1 ? coefficient.slice(0, exponent2 + 1) + "." + coefficient.slice(exponent2 + 1) : coefficient + new Array(exponent2 - coefficient.length + 2).join("0");
}
__name(formatRounded, "formatRounded");
const formatTypes = {
  "%": (x, p) => (x * 100).toFixed(p),
  "b": (x) => Math.round(x).toString(2),
  "c": (x) => x + "",
  "d": formatDecimal,
  "e": (x, p) => x.toExponential(p),
  "f": (x, p) => x.toFixed(p),
  "g": (x, p) => x.toPrecision(p),
  "o": (x) => Math.round(x).toString(8),
  "p": (x, p) => formatRounded(x * 100, p),
  "r": formatRounded,
  "s": formatPrefixAuto,
  "X": (x) => Math.round(x).toString(16).toUpperCase(),
  "x": (x) => Math.round(x).toString(16)
};
function identity$1(x) {
  return x;
}
__name(identity$1, "identity$1");
var map = Array.prototype.map, prefixes = ["y", "z", "a", "f", "p", "n", "\xB5", "m", "", "k", "M", "G", "T", "P", "E", "Z", "Y"];
function formatLocale(locale2) {
  var group = locale2.grouping === void 0 || locale2.thousands === void 0 ? identity$1 : formatGroup(map.call(locale2.grouping, Number), locale2.thousands + ""), currencyPrefix = locale2.currency === void 0 ? "" : locale2.currency[0] + "", currencySuffix = locale2.currency === void 0 ? "" : locale2.currency[1] + "", decimal = locale2.decimal === void 0 ? "." : locale2.decimal + "", numerals = locale2.numerals === void 0 ? identity$1 : formatNumerals(map.call(locale2.numerals, String)), percent = locale2.percent === void 0 ? "%" : locale2.percent + "", minus = locale2.minus === void 0 ? "\u2212" : locale2.minus + "", nan = locale2.nan === void 0 ? "NaN" : locale2.nan + "";
  function newFormat(specifier) {
    specifier = formatSpecifier(specifier);
    var fill = specifier.fill, align = specifier.align, sign = specifier.sign, symbol = specifier.symbol, zero2 = specifier.zero, width = specifier.width, comma = specifier.comma, precision = specifier.precision, trim = specifier.trim, type = specifier.type;
    if (type === "n")
      comma = true, type = "g";
    else if (!formatTypes[type])
      precision === void 0 && (precision = 12), trim = true, type = "g";
    if (zero2 || fill === "0" && align === "=")
      zero2 = true, fill = "0", align = "=";
    var prefix = symbol === "$" ? currencyPrefix : symbol === "#" && /[boxX]/.test(type) ? "0" + type.toLowerCase() : "", suffix = symbol === "$" ? currencySuffix : /[%p]/.test(type) ? percent : "";
    var formatType = formatTypes[type], maybeSuffix = /[defgprs%]/.test(type);
    precision = precision === void 0 ? 6 : /[gprs]/.test(type) ? Math.max(1, Math.min(21, precision)) : Math.max(0, Math.min(20, precision));
    function format2(value) {
      var valuePrefix = prefix, valueSuffix = suffix, i, n, c;
      if (type === "c") {
        valueSuffix = formatType(value) + valueSuffix;
        value = "";
      } else {
        value = +value;
        var valueNegative = value < 0 || 1 / value < 0;
        value = isNaN(value) ? nan : formatType(Math.abs(value), precision);
        if (trim)
          value = formatTrim(value);
        if (valueNegative && +value === 0 && sign !== "+")
          valueNegative = false;
        valuePrefix = (valueNegative ? sign === "(" ? sign : minus : sign === "-" || sign === "(" ? "" : sign) + valuePrefix;
        valueSuffix = (type === "s" ? prefixes[8 + prefixExponent / 3] : "") + valueSuffix + (valueNegative && sign === "(" ? ")" : "");
        if (maybeSuffix) {
          i = -1, n = value.length;
          while (++i < n) {
            if (c = value.charCodeAt(i), 48 > c || c > 57) {
              valueSuffix = (c === 46 ? decimal + value.slice(i + 1) : value.slice(i)) + valueSuffix;
              value = value.slice(0, i);
              break;
            }
          }
        }
      }
      if (comma && !zero2)
        value = group(value, Infinity);
      var length = valuePrefix.length + value.length + valueSuffix.length, padding = length < width ? new Array(width - length + 1).join(fill) : "";
      if (comma && zero2)
        value = group(padding + value, padding.length ? width - valueSuffix.length : Infinity), padding = "";
      switch (align) {
        case "<":
          value = valuePrefix + value + valueSuffix + padding;
          break;
        case "=":
          value = valuePrefix + padding + value + valueSuffix;
          break;
        case "^":
          value = padding.slice(0, length = padding.length >> 1) + valuePrefix + value + valueSuffix + padding.slice(length);
          break;
        default:
          value = padding + valuePrefix + value + valueSuffix;
          break;
      }
      return numerals(value);
    }
    __name(format2, "format");
    format2.toString = function() {
      return specifier + "";
    };
    return format2;
  }
  __name(newFormat, "newFormat");
  function formatPrefix2(specifier, value) {
    var f = newFormat((specifier = formatSpecifier(specifier), specifier.type = "f", specifier)), e = Math.max(-8, Math.min(8, Math.floor(exponent(value) / 3))) * 3, k = Math.pow(10, -e), prefix = prefixes[8 + e / 3];
    return function(value2) {
      return f(k * value2) + prefix;
    };
  }
  __name(formatPrefix2, "formatPrefix");
  return {
    format: newFormat,
    formatPrefix: formatPrefix2
  };
}
__name(formatLocale, "formatLocale");
var locale;
var format;
var formatPrefix;
defaultLocale({
  thousands: ",",
  grouping: [3],
  currency: ["$", ""]
});
function defaultLocale(definition) {
  locale = formatLocale(definition);
  format = locale.format;
  formatPrefix = locale.formatPrefix;
  return locale;
}
__name(defaultLocale, "defaultLocale");
function precisionFixed(step) {
  return Math.max(0, -exponent(Math.abs(step)));
}
__name(precisionFixed, "precisionFixed");
function precisionPrefix(step, value) {
  return Math.max(0, Math.max(-8, Math.min(8, Math.floor(exponent(value) / 3))) * 3 - exponent(Math.abs(step)));
}
__name(precisionPrefix, "precisionPrefix");
function precisionRound(step, max) {
  step = Math.abs(step), max = Math.abs(max) - step;
  return Math.max(0, exponent(max) - exponent(step)) + 1;
}
__name(precisionRound, "precisionRound");
function initRange(domain, range2) {
  switch (arguments.length) {
    case 0:
      break;
    case 1:
      this.range(domain);
      break;
    default:
      this.range(range2).domain(domain);
      break;
  }
  return this;
}
__name(initRange, "initRange");
const implicit = Symbol("implicit");
function ordinal() {
  var index = new InternMap(), domain = [], range2 = [], unknown = implicit;
  function scale(d) {
    let i = index.get(d);
    if (i === void 0) {
      if (unknown !== implicit)
        return unknown;
      index.set(d, i = domain.push(d) - 1);
    }
    return range2[i % range2.length];
  }
  __name(scale, "scale");
  scale.domain = function(_) {
    if (!arguments.length)
      return domain.slice();
    domain = [], index = new InternMap();
    for (const value of _) {
      if (index.has(value))
        continue;
      index.set(value, domain.push(value) - 1);
    }
    return scale;
  };
  scale.range = function(_) {
    return arguments.length ? (range2 = Array.from(_), scale) : range2.slice();
  };
  scale.unknown = function(_) {
    return arguments.length ? (unknown = _, scale) : unknown;
  };
  scale.copy = function() {
    return ordinal(domain, range2).unknown(unknown);
  };
  initRange.apply(scale, arguments);
  return scale;
}
__name(ordinal, "ordinal");
function band() {
  var scale = ordinal().unknown(void 0), domain = scale.domain, ordinalRange = scale.range, r0 = 0, r1 = 1, step, bandwidth, round = false, paddingInner = 0, paddingOuter = 0, align = 0.5;
  delete scale.unknown;
  function rescale() {
    var n = domain().length, reverse = r1 < r0, start2 = reverse ? r1 : r0, stop = reverse ? r0 : r1;
    step = (stop - start2) / Math.max(1, n - paddingInner + paddingOuter * 2);
    if (round)
      step = Math.floor(step);
    start2 += (stop - start2 - step * (n - paddingInner)) * align;
    bandwidth = step * (1 - paddingInner);
    if (round)
      start2 = Math.round(start2), bandwidth = Math.round(bandwidth);
    var values = range(n).map(function(i) {
      return start2 + step * i;
    });
    return ordinalRange(reverse ? values.reverse() : values);
  }
  __name(rescale, "rescale");
  scale.domain = function(_) {
    return arguments.length ? (domain(_), rescale()) : domain();
  };
  scale.range = function(_) {
    return arguments.length ? ([r0, r1] = _, r0 = +r0, r1 = +r1, rescale()) : [r0, r1];
  };
  scale.rangeRound = function(_) {
    return [r0, r1] = _, r0 = +r0, r1 = +r1, round = true, rescale();
  };
  scale.bandwidth = function() {
    return bandwidth;
  };
  scale.step = function() {
    return step;
  };
  scale.round = function(_) {
    return arguments.length ? (round = !!_, rescale()) : round;
  };
  scale.padding = function(_) {
    return arguments.length ? (paddingInner = Math.min(1, paddingOuter = +_), rescale()) : paddingInner;
  };
  scale.paddingInner = function(_) {
    return arguments.length ? (paddingInner = Math.min(1, _), rescale()) : paddingInner;
  };
  scale.paddingOuter = function(_) {
    return arguments.length ? (paddingOuter = +_, rescale()) : paddingOuter;
  };
  scale.align = function(_) {
    return arguments.length ? (align = Math.max(0, Math.min(1, _)), rescale()) : align;
  };
  scale.copy = function() {
    return band(domain(), [r0, r1]).round(round).paddingInner(paddingInner).paddingOuter(paddingOuter).align(align);
  };
  return initRange.apply(rescale(), arguments);
}
__name(band, "band");
function constants(x) {
  return function() {
    return x;
  };
}
__name(constants, "constants");
function number(x) {
  return +x;
}
__name(number, "number");
var unit = [0, 1];
function identity(x) {
  return x;
}
__name(identity, "identity");
function normalize$1(a, b) {
  return (b -= a = +a) ? function(x) {
    return (x - a) / b;
  } : constants(isNaN(b) ? NaN : 0.5);
}
__name(normalize$1, "normalize$1");
function clamper(a, b) {
  var t;
  if (a > b)
    t = a, a = b, b = t;
  return function(x) {
    return Math.max(a, Math.min(b, x));
  };
}
__name(clamper, "clamper");
function bimap(domain, range2, interpolate2) {
  var d0 = domain[0], d1 = domain[1], r0 = range2[0], r1 = range2[1];
  if (d1 < d0)
    d0 = normalize$1(d1, d0), r0 = interpolate2(r1, r0);
  else
    d0 = normalize$1(d0, d1), r0 = interpolate2(r0, r1);
  return function(x) {
    return r0(d0(x));
  };
}
__name(bimap, "bimap");
function polymap(domain, range2, interpolate2) {
  var j = Math.min(domain.length, range2.length) - 1, d = new Array(j), r = new Array(j), i = -1;
  if (domain[j] < domain[0]) {
    domain = domain.slice().reverse();
    range2 = range2.slice().reverse();
  }
  while (++i < j) {
    d[i] = normalize$1(domain[i], domain[i + 1]);
    r[i] = interpolate2(range2[i], range2[i + 1]);
  }
  return function(x) {
    var i2 = bisect(domain, x, 1, j) - 1;
    return r[i2](d[i2](x));
  };
}
__name(polymap, "polymap");
function copy(source, target) {
  return target.domain(source.domain()).range(source.range()).interpolate(source.interpolate()).clamp(source.clamp()).unknown(source.unknown());
}
__name(copy, "copy");
function transformer() {
  var domain = unit, range2 = unit, interpolate2 = interpolate$1, transform, untransform, unknown, clamp = identity, piecewise, output, input;
  function rescale() {
    var n = Math.min(domain.length, range2.length);
    if (clamp !== identity)
      clamp = clamper(domain[0], domain[n - 1]);
    piecewise = n > 2 ? polymap : bimap;
    output = input = null;
    return scale;
  }
  __name(rescale, "rescale");
  function scale(x) {
    return x == null || isNaN(x = +x) ? unknown : (output || (output = piecewise(domain.map(transform), range2, interpolate2)))(transform(clamp(x)));
  }
  __name(scale, "scale");
  scale.invert = function(y) {
    return clamp(untransform((input || (input = piecewise(range2, domain.map(transform), interpolateNumber)))(y)));
  };
  scale.domain = function(_) {
    return arguments.length ? (domain = Array.from(_, number), rescale()) : domain.slice();
  };
  scale.range = function(_) {
    return arguments.length ? (range2 = Array.from(_), rescale()) : range2.slice();
  };
  scale.rangeRound = function(_) {
    return range2 = Array.from(_), interpolate2 = interpolateRound, rescale();
  };
  scale.clamp = function(_) {
    return arguments.length ? (clamp = _ ? true : identity, rescale()) : clamp !== identity;
  };
  scale.interpolate = function(_) {
    return arguments.length ? (interpolate2 = _, rescale()) : interpolate2;
  };
  scale.unknown = function(_) {
    return arguments.length ? (unknown = _, scale) : unknown;
  };
  return function(t, u) {
    transform = t, untransform = u;
    return rescale();
  };
}
__name(transformer, "transformer");
function continuous() {
  return transformer()(identity, identity);
}
__name(continuous, "continuous");
function tickFormat(start2, stop, count, specifier) {
  var step = tickStep(start2, stop, count), precision;
  specifier = formatSpecifier(specifier == null ? ",f" : specifier);
  switch (specifier.type) {
    case "s": {
      var value = Math.max(Math.abs(start2), Math.abs(stop));
      if (specifier.precision == null && !isNaN(precision = precisionPrefix(step, value)))
        specifier.precision = precision;
      return formatPrefix(specifier, value);
    }
    case "":
    case "e":
    case "g":
    case "p":
    case "r": {
      if (specifier.precision == null && !isNaN(precision = precisionRound(step, Math.max(Math.abs(start2), Math.abs(stop)))))
        specifier.precision = precision - (specifier.type === "e");
      break;
    }
    case "f":
    case "%": {
      if (specifier.precision == null && !isNaN(precision = precisionFixed(step)))
        specifier.precision = precision - (specifier.type === "%") * 2;
      break;
    }
  }
  return format(specifier);
}
__name(tickFormat, "tickFormat");
function linearish(scale) {
  var domain = scale.domain;
  scale.ticks = function(count) {
    var d = domain();
    return ticks(d[0], d[d.length - 1], count == null ? 10 : count);
  };
  scale.tickFormat = function(count, specifier) {
    var d = domain();
    return tickFormat(d[0], d[d.length - 1], count == null ? 10 : count, specifier);
  };
  scale.nice = function(count) {
    if (count == null)
      count = 10;
    var d = domain();
    var i0 = 0;
    var i1 = d.length - 1;
    var start2 = d[i0];
    var stop = d[i1];
    var prestep;
    var step;
    var maxIter = 10;
    if (stop < start2) {
      step = start2, start2 = stop, stop = step;
      step = i0, i0 = i1, i1 = step;
    }
    while (maxIter-- > 0) {
      step = tickIncrement(start2, stop, count);
      if (step === prestep) {
        d[i0] = start2;
        d[i1] = stop;
        return domain(d);
      } else if (step > 0) {
        start2 = Math.floor(start2 / step) * step;
        stop = Math.ceil(stop / step) * step;
      } else if (step < 0) {
        start2 = Math.ceil(start2 * step) / step;
        stop = Math.floor(stop * step) / step;
      } else {
        break;
      }
      prestep = step;
    }
    return scale;
  };
  return scale;
}
__name(linearish, "linearish");
function linear() {
  var scale = continuous();
  scale.copy = function() {
    return copy(scale, linear());
  };
  initRange.apply(scale, arguments);
  return linearish(scale);
}
__name(linear, "linear");
function constant(x) {
  return /* @__PURE__ */ __name(function constant2() {
    return x;
  }, "constant");
}
__name(constant, "constant");
function array(x) {
  return typeof x === "object" && "length" in x ? x : Array.from(x);
}
__name(array, "array");
function none$1(series, order) {
  if (!((n = series.length) > 1))
    return;
  for (var i = 1, j, s0, s1 = series[order[0]], n, m = s1.length; i < n; ++i) {
    s0 = s1, s1 = series[order[i]];
    for (j = 0; j < m; ++j) {
      s1[j][1] += s1[j][0] = isNaN(s0[j][1]) ? s0[j][0] : s0[j][1];
    }
  }
}
__name(none$1, "none$1");
function none(series) {
  var n = series.length, o = new Array(n);
  while (--n >= 0)
    o[n] = n;
  return o;
}
__name(none, "none");
function stackValue(d, key) {
  return d[key];
}
__name(stackValue, "stackValue");
function stackSeries(key) {
  const series = [];
  series.key = key;
  return series;
}
__name(stackSeries, "stackSeries");
function stack() {
  var keys = constant([]), order = none, offset = none$1, value = stackValue;
  function stack2(data) {
    var sz = Array.from(keys.apply(this, arguments), stackSeries), i, n = sz.length, j = -1, oz;
    for (const d of data) {
      for (i = 0, ++j; i < n; ++i) {
        (sz[i][j] = [0, +value(d, sz[i].key, j, data)]).data = d;
      }
    }
    for (i = 0, oz = array(order(sz)); i < n; ++i) {
      sz[oz[i]].index = i;
    }
    offset(sz, oz);
    return sz;
  }
  __name(stack2, "stack");
  stack2.keys = function(_) {
    return arguments.length ? (keys = typeof _ === "function" ? _ : constant(Array.from(_)), stack2) : keys;
  };
  stack2.value = function(_) {
    return arguments.length ? (value = typeof _ === "function" ? _ : constant(+_), stack2) : value;
  };
  stack2.order = function(_) {
    return arguments.length ? (order = _ == null ? none : typeof _ === "function" ? _ : constant(Array.from(_)), stack2) : order;
  };
  stack2.offset = function(_) {
    return arguments.length ? (offset = _ == null ? none$1 : _, stack2) : offset;
  };
  return stack2;
}
__name(stack, "stack");
function Transform(k, x, y) {
  this.k = k;
  this.x = x;
  this.y = y;
}
__name(Transform, "Transform");
Transform.prototype = {
  constructor: Transform,
  scale: function(k) {
    return k === 1 ? this : new Transform(this.k * k, this.x, this.y);
  },
  translate: function(x, y) {
    return x === 0 & y === 0 ? this : new Transform(this.k, this.x + this.k * x, this.y + this.k * y);
  },
  apply: function(point) {
    return [point[0] * this.k + this.x, point[1] * this.k + this.y];
  },
  applyX: function(x) {
    return x * this.k + this.x;
  },
  applyY: function(y) {
    return y * this.k + this.y;
  },
  invert: function(location) {
    return [(location[0] - this.x) / this.k, (location[1] - this.y) / this.k];
  },
  invertX: function(x) {
    return (x - this.x) / this.k;
  },
  invertY: function(y) {
    return (y - this.y) / this.k;
  },
  rescaleX: function(x) {
    return x.copy().domain(x.range().map(this.invertX, this).map(x.invert, x));
  },
  rescaleY: function(y) {
    return y.copy().domain(y.range().map(this.invertY, this).map(y.invert, y));
  },
  toString: function() {
    return "translate(" + this.x + "," + this.y + ") scale(" + this.k + ")";
  }
};
new Transform(1, 0, 0);
Transform.prototype;
const container$2 = "_container_970ix_1";
const content = "_content_970ix_14";
const tooltipStyles = {
  container: container$2,
  content
};
const Tooltip = React.forwardRef((_, ref) => /* @__PURE__ */ React__default.default.createElement("div", {
  className: tooltipStyles.container,
  ref
}, /* @__PURE__ */ React__default.default.createElement("div", {
  className: tooltipStyles.content
})));
Tooltip.displayName = "Tooltip";
const useWindowSize = /* @__PURE__ */ __name(() => {
  const [windowSize, setWindowSize] = React.useState({
    width: void 0,
    height: void 0
  });
  React.useEffect(() => {
    function handleResize() {
      setWindowSize({
        width: window.innerWidth,
        height: window.innerHeight
      });
    }
    __name(handleResize, "handleResize");
    handleResize();
    window.addEventListener("resize", handleResize);
    return () => window.removeEventListener("resize", handleResize);
  }, []);
  return windowSize;
}, "useWindowSize");
const arrow$1 = "_arrow_plu8n_1";
const rotate180$1 = "_rotate180_plu8n_6";
const header = "_header_plu8n_10";
const subheadersContainer = "_subheadersContainer_plu8n_16";
const subheaderContainer = "_subheaderContainer_plu8n_20";
const subheaderLabel = "_subheaderLabel_plu8n_27";
const colorSquare = "_colorSquare_plu8n_33";
const chartTitle = "_chartTitle_plu8n_40";
const pointer = "_pointer_plu8n_44";
const styles$3 = {
  arrow: arrow$1,
  rotate180: rotate180$1,
  header,
  subheadersContainer,
  subheaderContainer,
  subheaderLabel,
  colorSquare,
  chartTitle,
  pointer
};
const BAR_SPACING = 7;
const CHARACTER_WIDTH_MONO_SIZE_12 = 7.204;
const MAX_MARGIN_LEFT = 230;
const colorLegend = {
  time: {
    color: "#1f990f",
    borderColor: "#1f990f",
    label: "Time"
  },
  totalTime: {
    color: "#3058d1",
    borderColor: "#3058d1",
    label: "Total Time"
  }
};
const dataToStack = /* @__PURE__ */ __name((data) => {
  const stacker = stack().keys(["totalTime", "time"]);
  return stacker(data);
}, "dataToStack");
const normalize = /* @__PURE__ */ __name((data, minBegin) => {
  return data.map((datum2) => ({
    ...datum2,
    relativeBegin: datum2.totalBegin - minBegin
  }));
}, "normalize");
const getFormattedNumber = /* @__PURE__ */ __name((numberMs) => {
  return `${format(`0.3f`)(numberMs)} ms`;
}, "getFormattedNumber");
const WaterfallChart = /* @__PURE__ */ __name(({ data, limits, filters }) => {
  const { width: windowInnerWidth = window.innerWidth } = useWindowSize();
  const chartRef = React.useRef(null);
  const marginChartRef = React.useRef(null);
  const xAxisRef = React.useRef(null);
  const yAxisRef = React.useRef(null);
  const dataRef = React.useRef(null);
  const toolTipRef = React.useRef(null);
  const neededMarginLeft = CHARACTER_WIDTH_MONO_SIZE_12 * limits.pathLength + 15;
  const marginLeft = Math.min(...[neededMarginLeft, MAX_MARGIN_LEFT]);
  const { dimensions, margins } = React.useMemo(() => {
    const margins2 = {
      top: 50,
      right: 60,
      left: marginLeft,
      bottom: 30
    };
    return {
      dimensions: {
        width: windowInnerWidth * 0.8,
        height: data.length * 30 + margins2.top + margins2.bottom
      },
      margins: margins2
    };
  }, [data, windowInnerWidth, marginLeft]);
  const innerWidth = dimensions.width - margins.left - margins.right;
  const innerHeight = dimensions.height - margins.top - margins.bottom;
  const xScale = linear().domain([0, limits.totalTime]).range([0, innerWidth]).nice();
  const yScale = band().domain(data.map(({ path }) => path)).range([0, innerHeight]).paddingInner(0.1);
  React.useEffect(() => {
    const maxCharactersToDisplay = Math.floor(marginLeft / CHARACTER_WIDTH_MONO_SIZE_12) - 1;
    let tooltip = select(toolTipRef.current);
    select(chartRef.current).attr("width", dimensions.width).attr("height", dimensions.height);
    select(marginChartRef.current).attr("transform", `translate(${margins.left},${margins.top})`).selectAll("text").attr("fill", "#000");
    const xAxisGroup = select(xAxisRef.current);
    xAxisGroup.selectAll("line").attr("transform", `translate(0,-5)`).attr("stroke-width", "0.5px").attr("stroke", "#000");
    xAxisGroup.selectAll(".domain").attr("stroke", "#000");
    xAxisGroup.call(
      axisTop(xScale).tickFormat((x) => getFormattedNumber(x * 1e-6)).tickSize(-innerHeight - 15).tickPadding(10)
    ).selectAll("text").attr("transform", "rotate(-30) translate(15, -1)");
    const yAxisGroup = select(yAxisRef.current);
    yAxisGroup.selectAll(".domain").attr("stroke", "#000");
    yAxisGroup.selectAll("line").attr("stroke", "#000");
    yAxisGroup.call(axisLeft(yScale)).selectAll("text").each(function(text) {
      const shortenedPath = textShortener(text, maxCharactersToDisplay);
      select(this).text(shortenedPath);
    }).attr("font-size", 12).attr("font-family", "monospace").select(".domain").attr("stroke", "#000");
    const stackedData = dataToStack(normalize(data, limits.totalBegin));
    const dataGroup = select(dataRef.current);
    const barGroups = dataGroup.selectAll("g").data(stackedData).join("g").attr("fill", ({ key }) => colorLegend[key].color).attr("stroke", ({ key }) => colorLegend[key].borderColor).attr("stroke-width", "1px");
    const rect = barGroups.selectAll("rect").data((d) => d).join("rect");
    rect.transition().attr("rx", 3).attr("x", (d) => xScale(d.data.relativeBegin)).attr("y", (d) => yScale(d.data.path)).attr("height", yScale.bandwidth() - BAR_SPACING).attr("width", ([start2, end]) => xScale(end) - xScale(start2)).attr("transform", `translate(2,${BAR_SPACING / 2})`).attr("pointer-events", "all");
    rect.on("mouseover", function(_, d) {
      select(this).style("opacity", 0.7);
      tooltip.style("opacity", 1);
      tooltip.select(`.${tooltipStyles.content}`).text("");
      tooltip.select(`.${tooltipStyles.content}`).append("span").html(`Path - ${d.data.path}</br>`);
      Object.keys(colorLegend).forEach((key) => {
        tooltip.select(`.${tooltipStyles.content}`).append("span").html(
          `${colorLegend[key].label} - ${getFormattedNumber(
            d.data[key] * 1e-6
          )}</br>`
        );
      });
    }).on("mouseout", function() {
      tooltip.style("opacity", 0);
      select(this).style("opacity", 1);
    }).on("mousemove", ({ clientX, clientY }) => {
      tooltip.style("left", `${clientX}px`);
      tooltip.style("top", `${clientY}px`);
    });
  }, [
    data,
    xScale,
    yScale,
    innerHeight,
    dimensions,
    limits,
    margins,
    marginLeft
  ]);
  return /* @__PURE__ */ React__default.default.createElement(React__default.default.Fragment, null, /* @__PURE__ */ React__default.default.createElement("div", {
    className: styles$3.header
  }, /* @__PURE__ */ React__default.default.createElement("div", {
    className: styles$3.subheadersContainer
  }, filters.map(({ onClick, order, label }) => {
    return /* @__PURE__ */ React__default.default.createElement("div", {
      key: label,
      onClick,
      className: `${styles$3.subheaderContainer} ${styles$3.pointer}`
    }, order !== 0 && /* @__PURE__ */ React__default.default.createElement(SvgArrow, {
      fill: "currentColor",
      className: `${styles$3.arrow} ${order > 0 ? styles$3.rotate180 : ""}`,
      alt: `arrow-${order > 0 ? "up" : "down"}`
    }), /* @__PURE__ */ React__default.default.createElement("p", {
      className: styles$3.subheaderLabel
    }, label));
  })), /* @__PURE__ */ React__default.default.createElement("h3", {
    className: styles$3.chartTitle
  }, "Profiler Waterfall View"), /* @__PURE__ */ React__default.default.createElement("div", {
    className: styles$3.subheadersContainer
  }, Object.values(colorLegend).map(({ color: color2, label }) => /* @__PURE__ */ React__default.default.createElement("div", {
    key: label,
    className: styles$3.subheaderContainer
  }, /* @__PURE__ */ React__default.default.createElement("p", {
    className: styles$3.subheaderLabel
  }, label), /* @__PURE__ */ React__default.default.createElement("div", {
    className: styles$3.colorSquare,
    style: { backgroundColor: color2 }
  }))))), /* @__PURE__ */ React__default.default.createElement("svg", {
    ref: chartRef,
    "data-testid": "waterfall-chart"
  }, /* @__PURE__ */ React__default.default.createElement("g", {
    ref: marginChartRef
  }, /* @__PURE__ */ React__default.default.createElement("g", {
    ref: xAxisRef
  }), /* @__PURE__ */ React__default.default.createElement("g", {
    ref: yAxisRef
  }), /* @__PURE__ */ React__default.default.createElement("g", {
    ref: dataRef
  }))), /* @__PURE__ */ React__default.default.createElement(Tooltip, {
    ref: toolTipRef
  }));
}, "WaterfallChart");
const Profiler = /* @__PURE__ */ __name(() => {
  const {
    profiler,
    searchByPath,
    changePathOrder,
    changeTimeOrder,
    changeTotalOrder,
    timeOrder,
    pathOrder,
    totalOrder,
    limits
  } = useProfiler();
  const [isModalOpen, setIsModalOpen] = React.useState(false);
  const tableHeaders = React__default.default.useMemo(() => {
    return [
      {
        label: "Path",
        order: pathOrder,
        onClick: changePathOrder,
        alignmentLeft: true
      },
      {
        label: "Time (ms)",
        order: timeOrder,
        onClick: changeTimeOrder,
        alignmentLeft: false
      },
      {
        label: "Total (ms)",
        order: totalOrder,
        onClick: changeTotalOrder,
        alignmentLeft: false
      }
    ];
  }, [
    pathOrder,
    changePathOrder,
    timeOrder,
    changeTimeOrder,
    totalOrder,
    changeTotalOrder
  ]);
  return /* @__PURE__ */ React__default.default.createElement(React__default.default.Fragment, null, isModalOpen && /* @__PURE__ */ React__default.default.createElement(Modal, {
    isOpen: isModalOpen,
    closeModal: () => setIsModalOpen(false)
  }, /* @__PURE__ */ React__default.default.createElement(WaterfallChart, {
    data: profiler,
    filters: tableHeaders,
    limits
  })), /* @__PURE__ */ React__default.default.createElement("div", {
    className: styles$5.headerContainer
  }, /* @__PURE__ */ React__default.default.createElement("div", {
    className: styles$5.searchContainer
  }, /* @__PURE__ */ React__default.default.createElement("input", {
    className: styles$5.searchInput,
    type: "text",
    onChange: searchByPath,
    name: "searchPath",
    required: true
  }), /* @__PURE__ */ React__default.default.createElement("label", {
    htmlFor: "searchPath",
    className: styles$5.searchLabel
  }, "Search by path")), profiler && profiler.length > 0 ? /* @__PURE__ */ React__default.default.createElement("div", {
    className: styles$5.chartIconContainer,
    onClick: () => setIsModalOpen(true),
    "data-testid": "open-profiler-waterfall-chart"
  }, /* @__PURE__ */ React__default.default.createElement(SvgChart, {
    fill: "currentColor",
    className: styles$5.chartIcon
  })) : null), /* @__PURE__ */ React__default.default.createElement("table", {
    className: styles$5.explainData
  }, /* @__PURE__ */ React__default.default.createElement("thead", null, /* @__PURE__ */ React__default.default.createElement("tr", null, tableHeaders.map(({ onClick, order, label, alignmentLeft }) => /* @__PURE__ */ React__default.default.createElement("th", {
    key: label,
    onClick,
    className: `${styles$5.th} ${alignmentLeft ? styles$5.tableCellAlignLeft : styles$5.tableCellAlignRight}`
  }, /* @__PURE__ */ React__default.default.createElement("div", {
    className: `${styles$5.thContent}
                ${alignmentLeft ? styles$5.justifyFlexStart : styles$5.justifyFlexEnd}`
  }, order !== 0 && /* @__PURE__ */ React__default.default.createElement(SvgArrow, {
    fill: "currentColor",
    className: `${styles$5.arrow} ${order > 0 ? styles$5.rotate180 : ""}`,
    alt: `arrow-${order > 0 ? "up" : "down"}`
  }), /* @__PURE__ */ React__default.default.createElement("p", null, label)))))), /* @__PURE__ */ React__default.default.createElement("tbody", null, profiler && profiler.length > 0 ? profiler.map(({ path, time, totalTime }) => {
    const timeMs = time * 1e-6;
    const totalTimeMs = totalTime * 1e-6;
    return /* @__PURE__ */ React__default.default.createElement("tr", {
      key: path
    }, /* @__PURE__ */ React__default.default.createElement("td", null, path), /* @__PURE__ */ React__default.default.createElement("td", {
      style: {
        color: getColorByLimit(time / limits.time)
      },
      className: styles$5.tableCellAlignRight
    }, timeMs.toFixed(2)), /* @__PURE__ */ React__default.default.createElement("td", {
      style: {
        color: getColorByLimit(totalTime / limits.totalTime)
      },
      className: styles$5.tableCellAlignRight
    }, totalTimeMs.toFixed(2)));
  }) : /* @__PURE__ */ React__default.default.createElement("tr", null, /* @__PURE__ */ React__default.default.createElement("td", null, "No entry found")))));
}, "Profiler");
const useResolverCalls = /* @__PURE__ */ __name(() => {
  const initialResolverCalls = React.useMemo(
    () => explainDataManager.getResolverCallsData(),
    []
  );
  const [resolverCalls, setResolverCalls] = React.useState(initialResolverCalls);
  const [defaultResolverCalls, setDefaultResolverCalls] = React.useState(initialResolverCalls);
  const [keyOrder, setKeyOrder] = React.useState(0);
  const [countOrder, setCountOrder] = React.useState(0);
  React.useEffect(() => {
    const eventListener = explainDataManager.addEventListener(
      "updateExplainData",
      (e, value) => {
        const resolverCalls2 = e.target.explainData.resolverCalls;
        setDefaultResolverCalls(() => resolverCalls2 || []);
        setResolverCalls((_) => resolverCalls2 || []);
      }
    );
    return () => {
      explainDataManager.removeEventListener("updateExplainData", eventListener);
    };
  }, []);
  const searchByField = React.useCallback(
    (fieldName) => {
      return (event) => {
        setResolverCalls((_) => {
          return defaultResolverCalls.filter((element) => {
            return element[fieldName].includes(event.target.value);
          });
        });
      };
    },
    [defaultResolverCalls]
  );
  const sort = React.useCallback((fieldName = "key") => {
    return (order) => {
      let localOrder = order;
      if (!order || order === 0) {
        return;
      } else if (order >= 1) {
        localOrder = 1;
      } else {
        localOrder = -1;
      }
      setResolverCalls((prevResolverCalls) => {
        return prevResolverCalls.slice().sort((a, b) => {
          return localOrder * `${a[fieldName]}`.localeCompare(`${b[fieldName]}`, void 0, {
            numeric: fieldName !== "key"
          });
        });
      });
    };
  }, []);
  const changeKeyOrder = React.useCallback(() => {
    if (keyOrder !== 0) {
      setKeyOrder((prev) => -prev);
    } else {
      setKeyOrder(1);
    }
    setCountOrder(0);
  }, [keyOrder]);
  const changeCountOrder = React.useCallback(() => {
    if (countOrder !== 0) {
      setCountOrder((prev) => -prev);
    } else {
      setCountOrder(1);
    }
    setKeyOrder(0);
  }, [countOrder]);
  React.useEffect(() => {
    if (keyOrder) {
      const sortKey = sort("key");
      sortKey(keyOrder);
    }
  }, [keyOrder, sort]);
  React.useEffect(() => {
    if (countOrder) {
      const sortCount = sort("count");
      sortCount(countOrder);
    }
  }, [countOrder, sort]);
  return {
    resolverCalls,
    searchByKey: searchByField("key"),
    countOrder,
    changeCountOrder,
    keyOrder,
    changeKeyOrder
  };
}, "useResolverCalls");
const container$1 = "_container_6qy85_1";
const explainData = "_explainData_6qy85_5";
const searchContainer = "_searchContainer_6qy85_9";
const searchInput = "_searchInput_6qy85_13";
const searchLabel = "_searchLabel_6qy85_28";
const th = "_th_6qy85_40";
const arrow = "_arrow_6qy85_46";
const rotate180 = "_rotate180_6qy85_51";
const thContent = "_thContent_6qy85_55";
const justifyFlexStart = "_justifyFlexStart_6qy85_60";
const justifyFlexEnd = "_justifyFlexEnd_6qy85_64";
const tableCellAlignLeft = "_tableCellAlignLeft_6qy85_68";
const tableCellAlignRight = "_tableCellAlignRight_6qy85_72";
const styles$2 = {
  container: container$1,
  explainData,
  searchContainer,
  searchInput,
  searchLabel,
  th,
  arrow,
  rotate180,
  thContent,
  justifyFlexStart,
  justifyFlexEnd,
  tableCellAlignLeft,
  tableCellAlignRight
};
const ResolverCalls = /* @__PURE__ */ __name(() => {
  const {
    resolverCalls,
    countOrder,
    changeCountOrder,
    keyOrder,
    changeKeyOrder,
    searchByKey
  } = useResolverCalls();
  const tableHeaders = React.useMemo(() => {
    return [
      {
        label: "Key",
        order: keyOrder,
        onClick: changeKeyOrder,
        alignmentLeft: true
      },
      {
        label: "Count",
        order: countOrder,
        onClick: changeCountOrder,
        alignmentLeft: false
      }
    ];
  }, [keyOrder, changeKeyOrder, countOrder, changeCountOrder]);
  return /* @__PURE__ */ React__default.default.createElement(React__default.default.Fragment, null, /* @__PURE__ */ React__default.default.createElement("div", {
    className: styles$2.searchContainer
  }, /* @__PURE__ */ React__default.default.createElement("input", {
    className: styles$2.searchInput,
    type: "text",
    onChange: searchByKey,
    name: "searchKey",
    required: true
  }), /* @__PURE__ */ React__default.default.createElement("label", {
    htmlFor: "searchKey",
    className: styles$2.searchLabel
  }, "Search by key")), /* @__PURE__ */ React__default.default.createElement("table", {
    className: styles$2.explainData
  }, /* @__PURE__ */ React__default.default.createElement("thead", null, /* @__PURE__ */ React__default.default.createElement("tr", null, tableHeaders.map(({ onClick, order, label, alignmentLeft }) => /* @__PURE__ */ React__default.default.createElement("th", {
    key: label,
    onClick,
    className: `${styles$2.th} ${alignmentLeft ? styles$2.tableCellAlignLeft : styles$2.tableCellAlignRight}`
  }, /* @__PURE__ */ React__default.default.createElement("div", {
    className: `${styles$2.thContent}
            ${alignmentLeft ? styles$2.justifyFlexStart : styles$2.justifyFlexEnd}`
  }, order !== 0 && /* @__PURE__ */ React__default.default.createElement(SvgArrow, {
    fill: "currentColor",
    className: `${styles$2.arrow} ${order > 0 ? styles$2.rotate180 : ""}`,
    alt: `arrow-${order > 0 ? "up" : "down"}`
  }), /* @__PURE__ */ React__default.default.createElement("p", null, label)))))), /* @__PURE__ */ React__default.default.createElement("tbody", null, resolverCalls && resolverCalls.length > 0 ? resolverCalls.map(({ key, count }) => {
    return /* @__PURE__ */ React__default.default.createElement("tr", {
      key
    }, /* @__PURE__ */ React__default.default.createElement("td", null, key), /* @__PURE__ */ React__default.default.createElement("td", {
      className: styles$2.tableCellAlignRight
    }, count));
  }) : /* @__PURE__ */ React__default.default.createElement("tr", null, /* @__PURE__ */ React__default.default.createElement("td", null, "No entry found")))));
}, "ResolverCalls");
const tabs = {
  profiler: {
    label: "Profiler",
    renderComponent: (props) => /* @__PURE__ */ React__default.default.createElement(Profiler, {
      ...props
    })
  },
  resolverCalls: {
    label: "Resolver Calls",
    renderComponent: (props) => /* @__PURE__ */ React__default.default.createElement(ResolverCalls, {
      ...props
    })
  }
};
const nav = "_nav_1j6xe_1";
const tab = "_tab_1j6xe_6";
const currentTab = "_currentTab_1j6xe_13";
const divider = "_divider_1j6xe_19";
const styles$1 = {
  nav,
  tab,
  currentTab,
  divider
};
const Tabs = /* @__PURE__ */ __name(({ handleTabClick, currentTab: currentTab2 }) => {
  return /* @__PURE__ */ React__default.default.createElement(React__default.default.Fragment, null, /* @__PURE__ */ React__default.default.createElement("nav", {
    className: styles$1.nav
  }, Object.entries(tabs).map(([key, value]) => {
    return /* @__PURE__ */ React__default.default.createElement("div", {
      key,
      onClick: () => handleTabClick(key),
      className: currentTab2 === key ? `${styles$1.currentTab} ${styles$1.tab}` : styles$1.tab
    }, value.label);
  })), /* @__PURE__ */ React__default.default.createElement("div", {
    className: styles$1.divider
  }));
}, "Tabs");
const useTabs = /* @__PURE__ */ __name(() => {
  const [currentTab2, setCurrentTab] = React.useState(
    explainDataManager.getCurrentTab()
  );
  const setNewCurrentTab = /* @__PURE__ */ __name((newTab) => {
    setCurrentTab(newTab);
    explainDataManager.setCurrentTab(newTab);
  }, "setNewCurrentTab");
  return { setCurrentTab: setNewCurrentTab, currentTab: currentTab2 };
}, "useTabs");
const SvgStopwatch = /* @__PURE__ */ __name((props) => /* @__PURE__ */ React__namespace.createElement("svg", {
  id: "Capa_1",
  xmlns: "http://www.w3.org/2000/svg",
  xmlnsXlink: "http://www.w3.org/1999/xlink",
  x: "0px",
  y: "0px",
  viewBox: "0 0 60 60",
  style: {
    enableBackground: "new 0 0 60 60"
  },
  xmlSpace: "preserve",
  ...props
}, /* @__PURE__ */ React__namespace.createElement("g", null, /* @__PURE__ */ React__namespace.createElement("path", {
  d: "M34.74,36.53l9.363-12.944c0.287-0.397,0.244-0.945-0.104-1.293c-0.348-0.346-0.896-0.39-1.293-0.104L29.76,31.555 c-0.844,0.614-1.375,1.563-1.456,2.604s0.296,2.06,1.033,2.797C30.01,37.629,30.904,38,31.854,38 C32.992,38,34.07,37.451,34.74,36.53z"
}), /* @__PURE__ */ React__namespace.createElement("path", {
  d: "M54.534,19.564c-0.01-0.021-0.01-0.043-0.021-0.064c-0.012-0.02-0.031-0.031-0.044-0.05 c-1.011-1.734-2.207-3.347-3.565-4.809l2.147-2.147l1.414,1.414l4.242-4.242l-4.242-4.243l-4.243,4.243l1.415,1.414l-2.147,2.147 c-1.462-1.358-3.074-2.555-4.809-3.566c-0.019-0.013-0.03-0.032-0.05-0.044c-0.021-0.012-0.043-0.011-0.064-0.022 c-3.093-1.782-6.568-2.969-10.272-3.404V5h1.5c1.379,0,2.5-1.121,2.5-2.5S37.172,0,35.793,0h-9c-1.379,0-2.5,1.121-2.5,2.5 s1.121,2.5,2.5,2.5h1.5v1.156c-1.08,0.115-2.158,0.291-3.224,0.535c-0.538,0.123-0.875,0.66-0.751,1.198 c0.123,0.538,0.66,0.874,1.198,0.751c0.946-0.217,1.902-0.378,2.86-0.485l0.991-0.075c0.335-0.025,0.635-0.043,0.925-0.057h0V10 c0,0.553,0.447,1,1,1s1-0.447,1-1V8.03c3.761,0.173,7.305,1.183,10.456,2.845l-0.986,1.708c-0.276,0.479-0.112,1.09,0.366,1.366 c0.157,0.091,0.329,0.134,0.499,0.134c0.346,0,0.682-0.18,0.867-0.5l0.983-1.704c3.129,1.985,5.787,4.643,7.772,7.772l-1.703,0.983 C50.07,20.91,49.906,21.521,50.183,22c0.186,0.321,0.521,0.5,0.867,0.5c0.17,0,0.342-0.043,0.499-0.134l1.707-0.986 c1.685,3.196,2.698,6.798,2.849,10.619H54.13c-0.553,0-1,0.447-1,1s0.447,1,1,1h1.975c-0.151,3.821-1.164,7.423-2.849,10.619 l-1.707-0.986c-0.478-0.277-1.09-0.114-1.366,0.366c-0.276,0.479-0.112,1.09,0.366,1.366l1.703,0.983 c-1.985,3.129-4.643,5.787-7.772,7.772l-0.983-1.703c-0.277-0.48-0.89-0.644-1.366-0.366c-0.479,0.276-0.643,0.888-0.366,1.366 l0.986,1.707c-3.151,1.662-6.695,2.672-10.456,2.845V56c0-0.553-0.447-1-1-1s-1,0.447-1,1v1.976 c-1.597-0.055-3.199-0.255-4.776-0.617c-0.538-0.125-1.075,0.213-1.198,0.751c-0.124,0.538,0.213,1.075,0.751,1.198 C27.068,59.768,29.107,60,31.13,60c0.049,0,0.096-0.003,0.145-0.004c0.007,0,0.012,0.004,0.018,0.004 c0.008,0,0.015-0.005,0.023-0.005c4.807-0.033,9.317-1.331,13.219-3.573c0.031-0.014,0.064-0.021,0.094-0.039 c0.02-0.012,0.031-0.031,0.05-0.044c4.039-2.354,7.414-5.725,9.773-9.761c0.019-0.027,0.043-0.048,0.06-0.078 c0.012-0.021,0.011-0.043,0.021-0.064C56.817,42.476,58.13,37.89,58.13,33S56.817,23.524,54.534,19.564z"
}), /* @__PURE__ */ React__namespace.createElement("path", {
  d: "M22.293,13h-5c-1.104,0-2,0.896-2,2s0.896,2,2,2h5c1.104,0,2-0.896,2-2S23.397,13,22.293,13z"
}), /* @__PURE__ */ React__namespace.createElement("path", {
  d: "M22.293,20h-10c-1.104,0-2,0.896-2,2s0.896,2,2,2h10c1.104,0,2-0.896,2-2S23.397,20,22.293,20z"
}), /* @__PURE__ */ React__namespace.createElement("path", {
  d: "M22.293,27h-15c-1.104,0-2,0.896-2,2s0.896,2,2,2h15c1.104,0,2-0.896,2-2S23.397,27,22.293,27z"
}), /* @__PURE__ */ React__namespace.createElement("path", {
  d: "M22.293,34h-19c-1.104,0-2,0.896-2,2s0.896,2,2,2h19c1.104,0,2-0.896,2-2S23.397,34,22.293,34z"
}), /* @__PURE__ */ React__namespace.createElement("path", {
  d: "M22.293,41h-13c-1.104,0-2,0.896-2,2s0.896,2,2,2h13c1.104,0,2-0.896,2-2S23.397,41,22.293,41z"
}), /* @__PURE__ */ React__namespace.createElement("path", {
  d: "M22.293,48h-7c-1.104,0-2,0.896-2,2s0.896,2,2,2h7c1.104,0,2-0.896,2-2S23.397,48,22.293,48z"
}))), "SvgStopwatch");
const container = "_container_10z2l_1";
const styles = {
  container
};
function Content() {
  const { currentTab: currentTab2, setCurrentTab } = useTabs();
  const { renderComponent } = tabs[currentTab2];
  return /* @__PURE__ */ React__default.default.createElement("div", {
    className: styles.container
  }, /* @__PURE__ */ React__default.default.createElement(Tabs, {
    handleTabClick: setCurrentTab,
    currentTab: currentTab2
  }), /* @__PURE__ */ React__default.default.createElement("div", null, renderComponent()));
}
__name(Content, "Content");
function Icon() {
  return /* @__PURE__ */ React__default.default.createElement(SvgStopwatch, {
    fill: "currentColor",
    "data-testid": "plugin-icon"
  });
}
__name(Icon, "Icon");
function graphiqlExplainPlugin() {
  return umdPlugin();
}
__name(graphiqlExplainPlugin, "graphiqlExplainPlugin");
function umdPlugin() {
  return {
    title: "GraphiQL Explain",
    icon: () => /* @__PURE__ */ React__default.default.createElement(Icon, null),
    content: () => {
      return /* @__PURE__ */ React__default.default.createElement(Content, null);
    }
  };
}
__name(umdPlugin, "umdPlugin");
exports.graphiqlExplainPlugin = graphiqlExplainPlugin;
exports.parseFetchResponse = parseFetchResponse;
exports.umdPlugin = umdPlugin;
